from .. pyaz_utils import call_az
from . import account, container, container_rm, cors, directory, entity, file, fs, logging, message, metrics, queue, share, share_rm, table


def remove(account_key=None, account_name=None, connection_string=None, container_name=None, exclude_path=None, exclude_pattern=None, include_path=None, include_pattern=None, name=None, path=None, recursive=None, sas_token=None, share_name=None):
    '''
    Delete blobs or files from Azure Storage.
    '''
    return call_az("az storage remove", locals())


def copy(account_key=None, account_name=None, blob_type=None, cap_mbps=None, connection_string=None, content_type=None, destination=None, destination_blob=None, destination_container=None, destination_file_path=None, destination_share=None, exclude_path=None, exclude_pattern=None, follow_symlinks=None, include_path=None, include_pattern=None, preserve_s2s_access_tier=None, put_md5=None, recursive=None, sas_token=None, source=None, source_account_key=None, source_account_name=None, source_blob=None, source_connection_string=None, source_container=None, source_file_path=None, source_sas=None, source_share=None):
    '''
    Copy files or directories to or from Azure storage.
    '''
    return call_az("az storage copy", locals())




from ... pyaz_utils import call_az
from . import all_statistics, prep_release_status, task_counts


def create(account_endpoint=None, account_key=None, account_name=None, id=None, job_manager_task_command_line=None, job_manager_task_environment_settings=None, job_manager_task_id=None, job_manager_task_resource_files=None, job_max_task_retry_count=None, job_max_wall_clock_time=None, json_file=None, max_parallel_tasks=None, metadata=None, pool_id=None, priority=None, required_slots=None, uses_task_dependencies=None):
    '''
    Add a job to a Batch account.
    '''
    return call_az("az batch job create", locals())


def delete(job_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, yes=None):
    return call_az("az batch job delete", locals())


def show(job_id, account_endpoint=None, account_key=None, account_name=None, expand=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, select=None):
    return call_az("az batch job show", locals())


def set(job_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, job_max_task_retry_count=None, job_max_wall_clock_time=None, json_file=None, max_parallel_tasks=None, metadata=None, on_all_tasks_complete=None, pool_id=None, priority=None):
    '''
    Update the properties of a Batch job. Updating a property in a subgroup will reset the unspecified properties of that group.
    '''
    return call_az("az batch job set", locals())


def reset(job_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, job_max_task_retry_count=None, job_max_wall_clock_time=None, json_file=None, metadata=None, on_all_tasks_complete=None, pool_id=None, priority=None):
    '''
    Update the properties of a Batch job. Unspecified properties which can be updated are reset to their defaults.
    '''
    return call_az("az batch job reset", locals())


def list(account_endpoint=None, account_key=None, account_name=None, expand=None, filter=None, job_schedule_id=None, select=None):
    '''
    List all of the jobs or job schedule in a Batch account.
    '''
    return call_az("az batch job list", locals())


def disable(job_id, account_endpoint=None, account_key=None, account_name=None, disable_tasks=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None):
    return call_az("az batch job disable", locals())


def enable(job_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None):
    return call_az("az batch job enable", locals())


def stop(job_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, terminate_reason=None):
    '''
    Stop a running Batch job.
    '''
    return call_az("az batch job stop", locals())




from .... pyaz_utils import call_az

def acquire(blob_name, container_name, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_duration=None, proposed_lease_id=None, sas_token=None, tags_condition=None, timeout=None):
    '''
    Request a new lease.
    '''
    return call_az("az storage blob lease acquire", locals())


def break_(blob_name, container_name, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_break_period=None, sas_token=None, tags_condition=None, timeout=None):
    return call_az("az storage blob lease break", locals())


def change(blob_name, container_name, lease_id, proposed_lease_id, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, sas_token=None, tags_condition=None, timeout=None):
    return call_az("az storage blob lease change", locals())


def renew(blob_name, container_name, lease_id, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, sas_token=None, tags_condition=None, timeout=None):
    '''
    Renew the lease.
    '''
    return call_az("az storage blob lease renew", locals())


def release(blob_name, container_name, lease_id, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, sas_token=None, tags_condition=None, timeout=None):
    return call_az("az storage blob lease release", locals())




from ..... pyaz_utils import call_az

def list(eventhub_name, name, namespace_name, resource_group):
    '''
    Shows the connection strings of Authorizationrule for the Eventhub.
    '''
    return call_az("az eventhubs eventhub authorization-rule keys list", locals())


def renew(eventhub_name, key, name, namespace_name, resource_group, key_value=None):
    '''
    Regenerate the connection strings of Authorizationrule for the namespace.
    '''
    return call_az("az eventhubs eventhub authorization-rule keys renew", locals())




from ... pyaz_utils import call_az

def create(name, resource_group, workspace):
    '''
    Create an experiment.
    '''
    return call_az("az batchai experiment create", locals())


def show(name, resource_group, workspace):
    '''
    Show information about an experiment.
    '''
    return call_az("az batchai experiment show", locals())


def list(resource_group, workspace):
    '''
    List experiments.
    '''
    return call_az("az batchai experiment list", locals())


def delete(name, resource_group, workspace, no_wait=None, yes=None):
    '''
    Delete an experiment.
    '''
    return call_az("az batchai experiment delete", locals())




from .... pyaz_utils import call_az

def list(date_time_begin, date_time_end, granularity, metrics, profile_name, resource_group, actions=None, group_by=None, rule_types=None):
    return call_az("az afd waf-log-analytic metric list", locals())




from ... pyaz_utils import call_az

def list(resource_group, filter=None):
    '''
    List deployments at resource group.
    '''
    return call_az("az deployment group list", locals())


def show(name, resource_group):
    '''
    Show a deployment at resource group.
    '''
    return call_az("az deployment group show", locals())


def delete(name, resource_group, no_wait=None):
    '''
    Delete a deployment at resource group.
    '''
    return call_az("az deployment group delete", locals())


def validate(resource_group, handle_extended_json_format=None, mode=None, name=None, no_prompt=None, parameters=None, query_string=None, rollback_on_error=None, template_file=None, template_spec=None, template_uri=None):
    '''
    Validate whether a template is valid at resource group.
    '''
    return call_az("az deployment group validate", locals())


def create(resource_group, aux_subs=None, aux_tenants=None, confirm_with_what_if=None, handle_extended_json_format=None, mode=None, name=None, no_prompt=None, no_wait=None, parameters=None, proceed_if_no_change=None, query_string=None, rollback_on_error=None, template_file=None, template_spec=None, template_uri=None, what_if=None, what_if_exclude_change_types=None, what_if_result_format=None):
    '''
    Start a deployment at resource group.
    '''
    return call_az("az deployment group create", locals())


def what_if(resource_group, aux_tenants=None, exclude_change_types=None, mode=None, name=None, no_pretty_print=None, no_prompt=None, parameters=None, query_string=None, result_format=None, template_file=None, template_spec=None, template_uri=None):
    '''
    Execute a deployment What-If operation at resource group scope.
    '''
    return call_az("az deployment group what-if", locals())


def export(name, resource_group):
    '''
    Export the template used for a deployment.
    '''
    return call_az("az deployment group export", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a deployment condition is met.
    '''
    return call_az("az deployment group wait", locals())


def cancel(name, resource_group):
    '''
    Cancel a deployment at resource group.
    '''
    return call_az("az deployment group cancel", locals())




from .. pyaz_utils import call_az
from . import config, cors, function, hybrid_connection, identity, keys, plan, vnet_integration


def create(name, resource_group, storage_account, app_insights=None, app_insights_key=None, assign_identity=None, consumption_plan_location=None, deployment_container_image_name=None, deployment_local_git=None, deployment_source_branch=None, deployment_source_url=None, disable_app_insights=None, docker_registry_server_password=None, docker_registry_server_user=None, functions_version=None, os_type=None, plan=None, role=None, runtime=None, runtime_version=None, scope=None, subnet=None, tags=None, vnet=None):
    '''
    Create a function app.
    '''
    return call_az("az functionapp create", locals())


def list(resource_group=None):
    '''
    List function apps.
    '''
    return call_az("az functionapp list", locals())


def show(name, resource_group, slot=None):
    '''
    Get the details of a function app.
    '''
    return call_az("az functionapp show", locals())


def delete(name, resource_group, slot=None):
    '''
    Delete a function app.
    '''
    return call_az("az functionapp delete", locals())


def stop(name, resource_group, slot=None):
    '''
    Stop a function app.
    '''
    return call_az("az functionapp stop", locals())


def start(name, resource_group, slot=None):
    '''
    Start a function app.
    '''
    return call_az("az functionapp start", locals())


def restart(name, resource_group, slot=None):
    '''
    Restart a function app.
    '''
    return call_az("az functionapp restart", locals())


def list_consumption_locations():
    '''
    List available locations for running function apps.
    '''
    return call_az("az functionapp list-consumption-locations", locals())


def deploy(name, resource_group, async_=None, clean=None, ignore_stack=None, restart=None, slot=None, src_path=None, src_url=None, target_path=None, timeout=None, type=None):
    '''
    Deploys a provided artifact to Azure functionapp.
    '''
    return call_az("az functionapp deploy", locals())


def update(name, resource_group, add=None, force=None, force_string=None, plan=None, remove=None, set=None, slot=None):
    '''
    Update a function app.
    '''
    return call_az("az functionapp update", locals())




from ... pyaz_utils import call_az

def show(name, resource_group):
    '''
    Get the status of Classic Azure Monitor logs integration on an HDInsight cluster.
    '''
    return call_az("az hdinsight monitor show", locals())


def enable(name, resource_group, workspace, no_validation_timeout=None, primary_key=None):
    '''
    Enable the Classic Azure Monitor logs integration on an HDInsight cluster.
    '''
    return call_az("az hdinsight monitor enable", locals())


def disable(name, resource_group):
    '''
    Disable the Classic Azure Monitor logs integration on an HDInsight cluster.
    '''
    return call_az("az hdinsight monitor disable", locals())




from ..... pyaz_utils import call_az

def add(address_pool, identifier, lb_name, protocol, resource_group, type, port=None):
    '''
    Add one tunnel interface into the load balance tunnel interface pool.
    '''
    return call_az("az network lb address-pool tunnel-interface add", locals())


def update(address_pool, index, lb_name, resource_group, identifier=None, port=None, protocol=None, type=None):
    '''
    update one tunnel interface of load balance tunnel interface pool.
    '''
    return call_az("az network lb address-pool tunnel-interface update", locals())


def remove(address_pool, index, lb_name, resource_group):
    '''
    Remove one tunnel interface from the load balance tunnel interface pool.
    '''
    return call_az("az network lb address-pool tunnel-interface remove", locals())


def list(address_pool, lb_name, resource_group):
    '''
    List all tunnel interfacees of the load balance tunnel interface pool.
    '''
    return call_az("az network lb address-pool tunnel-interface list", locals())




from .. pyaz_utils import call_az
from . import agentpool, connected_registry, credential, encryption, helm, identity, network_rule, pack, private_endpoint_connection, private_link_resource, replication, repository, scope_map, task, taskrun, token, webhook


def check_name(name):
    '''
    Checks if an Azure Container Registry name is valid and available for use.
    '''
    return call_az("az acr check-name", locals())


def list(resource_group=None):
    '''
    Lists all the container registries under the current subscription.
    '''
    return call_az("az acr list", locals())


def create(name, resource_group, sku, admin_enabled=None, allow_exports=None, allow_trusted_services=None, default_action=None, identity=None, key_encryption_key=None, location=None, public_network_enabled=None, tags=None, workspace=None, zone_redundancy=None):
    '''
    Create an Azure Container Registry.
    '''
    return call_az("az acr create", locals())


def delete(name, resource_group=None, yes=None):
    '''
    Deletes an Azure Container Registry.
    '''
    return call_az("az acr delete", locals())


def show(name, resource_group=None):
    '''
    Get the details of an Azure Container Registry.
    '''
    return call_az("az acr show", locals())


def show_usage(name, resource_group=None):
    '''
    Get the storage usage for an Azure Container Registry.
    '''
    return call_az("az acr show-usage", locals())


def show_endpoints(name, resource_group=None):
    '''
    Display registry endpoints
    '''
    return call_az("az acr show-endpoints", locals())


def update(name, add=None, admin_enabled=None, allow_exports=None, allow_trusted_services=None, anonymous_pull_enabled=None, data_endpoint_enabled=None, default_action=None, force_string=None, public_network_enabled=None, remove=None, resource_group=None, set=None, sku=None, tags=None):
    '''
    Update an Azure Container Registry.
    '''
    return call_az("az acr update", locals())


def login(name, expose_token=None, password=None, resource_group=None, suffix=None, username=None):
    '''
    Log in to an Azure Container Registry through the Docker CLI.
    '''
    return call_az("az acr login", locals())


def import_(name, source, force=None, image=None, no_wait=None, password=None, registry=None, repository=None, resource_group=None, username=None):
    '''
    Imports an image to an Azure Container Registry from another Container Registry. Import removes the need to docker pull, docker tag, docker push. For larger images consider using `--no-wait`.
    '''
    return call_az("az acr import", locals())


def build(registry, agent_pool=None, auth_mode=None, build_arg=None, file=None, image=None, log_template=None, no_format=None, no_logs=None, no_push=None, no_wait=None, platform=None, resource_group=None, secret_build_arg=None, target=None, timeout=None):
    '''
    Queues a quick build, providing streaming logs for an Azure Container Registry.
    '''
    return call_az("az acr build", locals())


def run(registry, agent_pool=None, auth_mode=None, file=None, log_template=None, no_format=None, no_logs=None, no_wait=None, platform=None, resource_group=None, set=None, set_secret=None, timeout=None, values=None):
    '''
    Queues a quick run providing streamed logs for an Azure Container Registry.
    '''
    return call_az("az acr run", locals())


def check_health(ignore_errors=None, name=None, vnet=None, yes=None):
    '''
    Gets health information on the environment and optionally a target registry.
    '''
    return call_az("az acr check-health", locals())




from ..... pyaz_utils import call_az

def show(account_name, policy_id, rule_id, resource_group=None):
    '''
    Show the properties of specified rule in Object Replication Service Policy.
    '''
    return call_az("az storage account or-policy rule show", locals())


def list(account_name, policy_id, resource_group=None):
    '''
    List all the rules in the specified Object Replication Service Policy.
    '''
    return call_az("az storage account or-policy rule list", locals())


def add(account_name, destination_container, policy_id, source_container, min_creation_time=None, prefix_match=None, resource_group=None):
    '''
    Add rule to the specified Object Replication Service Policy.
    '''
    return call_az("az storage account or-policy rule add", locals())


def update(account_name, policy_id, rule_id, destination_container=None, min_creation_time=None, prefix_match=None, resource_group=None, source_container=None):
    '''
    Update rule properties to Object Replication Service Policy.
    '''
    return call_az("az storage account or-policy rule update", locals())


def remove(account_name, policy_id, rule_id, resource_group=None):
    '''
    Remove the specified rule from the specified Object Replication Service Policy.
    '''
    return call_az("az storage account or-policy rule remove", locals())




from ... pyaz_utils import call_az
from . import task


def create(location, name, resource_group, service_name, source_platform, target_platform, tags=None):
    '''
    Create a migration project which can contain multiple tasks.
    '''
    return call_az("az dms project create", locals())


def delete(name, resource_group, service_name, delete_running_tasks=None, yes=None):
    '''
    Delete a project.
    '''
    return call_az("az dms project delete", locals())


def list(resource_group, service_name):
    '''
    List the projects within an instance of DMS.
    '''
    return call_az("az dms project list", locals())


def show(name, resource_group, service_name):
    '''
    Show the details of a migration project.
    '''
    return call_az("az dms project show", locals())


def check_name(name, resource_group, service_name):
    '''
    Check if a given project name is available within a given instance of DMS as well as the name's validity.
    '''
    return call_az("az dms project check-name", locals())




from ... pyaz_utils import call_az

def delete(id):
    return call_az("az ad user delete", locals())


def show(id):
    return call_az("az ad user show", locals())


def list(display_name=None, filter=None, upn=None):
    '''
    List Azure Active Directory users.
    '''
    return call_az("az ad user list", locals())


def get_member_groups(id, security_enabled_only=None):
    '''
    Get groups of which the user is a member
    '''
    return call_az("az ad user get-member-groups", locals())


def create(display_name, password, user_principal_name, force_change_password_next_login=None, immutable_id=None, mail_nickname=None):
    '''
    Create an Azure Active Directory user.
    '''
    return call_az("az ad user create", locals())


def update(id, account_enabled=None, display_name=None, force_change_password_next_login=None, mail_nickname=None, password=None):
    '''
    Update Azure Active Directory users.
    '''
    return call_az("az ad user update", locals())




from .... pyaz_utils import call_az

def create(account_name, name, require_infrastructure_encryption=None, resource_group=None):
    '''
    Create an encryption scope within storage account.
    '''
    return call_az("az storage account encryption-scope create", locals())


def show(account_name, name, resource_group=None):
    '''
    Show properties for specified encryption scope within storage account.
    '''
    return call_az("az storage account encryption-scope show", locals())


def list(account_name, resource_group=None):
    '''
    List encryption scopes within storage account.
    '''
    return call_az("az storage account encryption-scope list", locals())


def update(account_name, name, resource_group=None, state=None):
    '''
    Update properties for specified encryption scope within storage account.
    '''
    return call_az("az storage account encryption-scope update", locals())




from ...... pyaz_utils import call_az
from . import rule_set


def add(match_variable, policy_name, resource_group, selector, selector_match_operator):
    '''
    Add an OWASP CRS exclusion rule to the WAF policy managed rules.
    '''
    return call_az("az network application-gateway waf-policy managed-rule exclusion add", locals())


def remove(policy_name, resource_group):
    '''
    Remove all OWASP CRS exclusion rules that are applied on a Waf policy managed rules.
    '''
    return call_az("az network application-gateway waf-policy managed-rule exclusion remove", locals())


def list(policy_name, resource_group):
    '''
    List all OWASP CRS exclusion rules that are applied on a Waf policy managed rules.
    '''
    return call_az("az network application-gateway waf-policy managed-rule exclusion list", locals())




from .... pyaz_utils import call_az

def delete(name, resource_group, if_match=None, yes=None):
    '''
    Delete a DNS zone and all associated records.
    '''
    return call_az("az network dns zone delete", locals())


def show(name, resource_group):
    '''
    Get a DNS zone parameters. Does not show DNS records within the zone.
    '''
    return call_az("az network dns zone show", locals())


def list(resource_group=None):
    '''
    List DNS zones.
    '''
    return call_az("az network dns zone list", locals())


def import_(file_name, name, resource_group):
    '''
    Create a DNS zone using a DNS zone file.
    '''
    return call_az("az network dns zone import", locals())


def export(name, resource_group, file_name=None):
    '''
    Export a DNS zone as a DNS zone file.
    '''
    return call_az("az network dns zone export", locals())


def create(name, resource_group, if_none_match=None, parent_name=None, registration_vnets=None, resolution_vnets=None, tags=None, zone_type=None):
    '''
    Create a DNS zone.
    '''
    return call_az("az network dns zone create", locals())


def update(name, resource_group, add=None, force_string=None, if_match=None, registration_vnets=None, remove=None, resolution_vnets=None, set=None, tags=None, zone_type=None):
    '''
    Update a DNS zone properties. Does not modify DNS records within the zone.
    '''
    return call_az("az network dns zone update", locals())




from ... pyaz_utils import call_az

def list(name, resource_group=None):
    '''
    list the private link resources supported for a registry
    '''
    return call_az("az acr private-link-resource list", locals())




from .... pyaz_utils import call_az
from . import ipsec_policy


def generate(name, resource_group, authentication_method=None, client_root_certificates=None, processor_architecture=None, radius_server_auth_certificate=None, use_legacy=None):
    '''
    Generate VPN client configuration.
    '''
    return call_az("az network vnet-gateway vpn-client generate", locals())


def show_url(name, resource_group):
    '''
    Retrieve a pre-generated VPN client configuration.
    '''
    return call_az("az network vnet-gateway vpn-client show-url", locals())


def show_health(name, resource_group):
    '''
    Get the VPN client connection health detail per P2S client connection of the virtual network gateway.
    '''
    return call_az("az network vnet-gateway vpn-client show-health", locals())




from ... pyaz_utils import call_az

def show(lab_name, name, resource_group, expand=None):
    return call_az("az lab custom-image show", locals())


def list(lab_name, resource_group, expand=None, filter=None, orderby=None, top=None):
    return call_az("az lab custom-image list", locals())


def delete(lab_name, name, resource_group):
    return call_az("az lab custom-image delete", locals())


def create(lab_name, name, os_state, os_type, resource_group, source_vm_id, author=None, description=None):
    '''
    Create a custom image in a DevTest Lab.
    '''
    return call_az("az lab custom-image create", locals())




from ... pyaz_utils import call_az

def create(cluster_name, name, resource_group, script_action_name, script_uri, access_mode=None, destination_port=None, disable_gateway_auth=None, edgenode_size=None, marketplace_id=None, no_validation_timeout=None, script_parameters=None, ssh_password=None, ssh_public_key=None, ssh_user=None, sub_domain_suffix=None, subnet=None, tags=None, type=None, vnet_name=None):
    '''
    Create an application for a HDInsight cluster.
    '''
    return call_az("az hdinsight application create", locals())


def show(cluster_name, name, resource_group):
    return call_az("az hdinsight application show", locals())


def list(cluster_name, resource_group):
    return call_az("az hdinsight application list", locals())


def wait(cluster_name, name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until an operation is complete.
    '''
    return call_az("az hdinsight application wait", locals())


def delete(cluster_name, name, resource_group, no_wait=None, yes=None):
    return call_az("az hdinsight application delete", locals())




from ... pyaz_utils import call_az
from . import site, sku


def create(name, resource_group, scale_unit, vendor, version, vhub, asn=None, boot_strap_config_blobs=None, cloud_init_config=None, cloud_init_config_blobs=None, location=None, tags=None):
    '''
    Create an Azure network virtual appliance.
    '''
    return call_az("az network virtual-appliance create", locals())


def update(name, resource_group, add=None, asn=None, cloud_init_config=None, force_string=None, remove=None, set=None):
    '''
    Update an Azure network virtual appliance.
    '''
    return call_az("az network virtual-appliance update", locals())


def show(name, resource_group, expand=None):
    '''
    Show the detail of an Azure network virtual appliance.
    '''
    return call_az("az network virtual-appliance show", locals())


def list(resource_group=None):
    '''
    List all Azure network virtual appliance.
    '''
    return call_az("az network virtual-appliance list", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete an Azure network virtual appliance.
    '''
    return call_az("az network virtual-appliance delete", locals())




from ... pyaz_utils import call_az
from . import operation


def create(resource_group, aux_subs=None, aux_tenants=None, handle_extended_json_format=None, mode=None, name=None, no_prompt=None, no_wait=None, parameters=None, rollback_on_error=None, template_file=None, template_uri=None):
    '''
    Start a deployment.
    '''
    return call_az("az group deployment create", locals())


def list(resource_group, filter=None, top=None):
    return call_az("az group deployment list", locals())


def show(name, resource_group):
    return call_az("az group deployment show", locals())


def delete(name, resource_group, no_wait=None):
    return call_az("az group deployment delete", locals())


def validate(resource_group, handle_extended_json_format=None, mode=None, no_prompt=None, parameters=None, rollback_on_error=None, template_file=None, template_uri=None):
    '''
    Validate whether a template is syntactically correct.
    '''
    return call_az("az group deployment validate", locals())


def export(name, resource_group):
    '''
    Export the template used for a deployment.
    '''
    return call_az("az group deployment export", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a deployment condition is met.
    '''
    return call_az("az group deployment wait", locals())


def cancel(name, resource_group):
    return call_az("az group deployment cancel", locals())




from ... pyaz_utils import call_az

def invoke(command_id, name, resource_group, parameters=None, scripts=None):
    '''
    Execute a specific run command on a vm.
    '''
    return call_az("az vm run-command invoke", locals())


def list(expand=None, location=None, resource_group=None, vm_name=None):
    '''
    The operation to get all run commands of a Virtual Machine. And Lists all available run commands for a subscription in a location.
    '''
    return call_az("az vm run-command list", locals())


def show(command_id=None, expand=None, instance_view=None, location=None, name=None, resource_group=None, vm_name=None):
    '''
    The operation to get the run command. And Gets specific run command for a subscription in a location.
    '''
    return call_az("az vm run-command show", locals())


def create(name, resource_group, vm_name, async_execution=None, command_id=None, error_blob_uri=None, location=None, no_wait=None, output_blob_uri=None, parameters=None, protected_parameters=None, run_as_password=None, run_as_user=None, script=None, script_uri=None, tags=None, timeout_in_seconds=None):
    '''
    The operation to create the run command.
    '''
    return call_az("az vm run-command create", locals())


def update(name, resource_group, vm_name, async_execution=None, command_id=None, error_blob_uri=None, location=None, no_wait=None, output_blob_uri=None, parameters=None, protected_parameters=None, run_as_password=None, run_as_user=None, script=None, script_uri=None, tags=None, timeout_in_seconds=None):
    '''
    The operation to update the run command.
    '''
    return call_az("az vm run-command update", locals())


def delete(name, resource_group, vm_name, no_wait=None, yes=None):
    '''
    The operation to delete the run command.
    '''
    return call_az("az vm run-command delete", locals())


def wait(command_id=None, created=None, custom=None, deleted=None, exists=None, expand=None, instance_view=None, interval=None, location=None, name=None, resource_group=None, timeout=None, updated=None, vm_name=None):
    '''
    Place the CLI in a waiting state until a condition of the res virtual-machine-run-command is met.
    '''
    return call_az("az vm run-command wait", locals())




from ... pyaz_utils import call_az

def upload(package, workspace_name, no_progress=None):
    '''
    Upload a local workspace package file to an Azure Synapse workspace.
    '''
    return call_az("az synapse workspace-package upload", locals())


def upload_batch(source, workspace_name, no_progress=None):
    '''
    Upload workspace package files from a local directory to an Azure Synapse workspace.
    '''
    return call_az("az synapse workspace-package upload-batch", locals())


def list(workspace_name):
    '''
    List workspace packages.
    '''
    return call_az("az synapse workspace-package list", locals())


def show(package_name, workspace_name):
    '''
    Get a workspace package.
    '''
    return call_az("az synapse workspace-package show", locals())


def delete(package_name, workspace_name, no_wait=None, yes=None):
    '''
    Delete a workspace package.
    '''
    return call_az("az synapse workspace-package delete", locals())




from ... pyaz_utils import call_az

def list(filter=None, skiptoken=None, top=None):
    return call_az("az billing period list", locals())


def show(name):
    return call_az("az billing period show", locals())




from .... pyaz_utils import call_az

def show(account, database_name, external_data_source_name):
    return call_az("az dla catalog external-data-source show", locals())


def list(account, database_name, count=None, filter=None, orderby=None, select=None, skip=None, top=None):
    return call_az("az dla catalog external-data-source list", locals())




from ... pyaz_utils import call_az
from . import encryption, mru, sp, storage


def show(name, resource_group=None):
    '''
    Show the details of an Azure Media Services account.
    '''
    return call_az("az ams account show", locals())


def delete(name, resource_group):
    '''
    Delete an Azure Media Services account.
    '''
    return call_az("az ams account delete", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update the details of an Azure Media Services account.
    '''
    return call_az("az ams account update", locals())


def list(resource_group=None):
    '''
    List Azure Media Services accounts for the entire subscription.
    '''
    return call_az("az ams account list", locals())


def create(name, resource_group, storage_account, location=None, mi_system_assigned=None, tags=None):
    '''
    Create an Azure Media Services account.
    '''
    return call_az("az ams account create", locals())


def check_name(name, location=None):
    '''
    Checks whether the Media Service resource name is available.
    '''
    return call_az("az ams account check-name", locals())




from ... pyaz_utils import call_az

def delete(name, registry_name, resource_group=None):
    '''
    Delete a private endpoint connection request for a container registry
    '''
    return call_az("az acr private-endpoint-connection delete", locals())


def show(name, registry_name, resource_group=None):
    '''
    Show details of a container registry's private endpoint connection
    '''
    return call_az("az acr private-endpoint-connection show", locals())


def list(registry_name, resource_group=None):
    '''
    List all private endpoint connections to a container registry
    '''
    return call_az("az acr private-endpoint-connection list", locals())


def approve(name, registry_name, description=None, resource_group=None):
    '''
    Approve a private endpoint connection request for a container registry
    '''
    return call_az("az acr private-endpoint-connection approve", locals())


def reject(name, registry_name, description=None, resource_group=None):
    '''
    Reject a private endpoint connection request for a container registry
    '''
    return call_az("az acr private-endpoint-connection reject", locals())




from .... pyaz_utils import call_az

def list(name, resource_group):
    '''
    List shared access keys of a domain.
    '''
    return call_az("az eventgrid domain key list", locals())


def regenerate(key_name, name, resource_group):
    '''
    Regenerate a shared access key of a domain.
    '''
    return call_az("az eventgrid domain key regenerate", locals())




from .... pyaz_utils import call_az

def add(gateway_name, name, resource_group, cipher_suites=None, client_auth_configuration=None, disabled_ssl_protocols=None, min_protocol_version=None, policy_name=None, policy_type=None, trusted_client_certificates=None):
    '''
    Add ssl profiles of the application gateway.
    '''
    return call_az("az network application-gateway ssl-profile add", locals())


def remove(gateway_name, name, resource_group):
    '''
    Remove an existing ssl profiles of the application gateway.
    '''
    return call_az("az network application-gateway ssl-profile remove", locals())


def list(gateway_name, resource_group):
    '''
    List the existing ssl profiles of the application gateway.
    '''
    return call_az("az network application-gateway ssl-profile list", locals())


def show(gateway_name, name, resource_group):
    '''
    Show an existing ssl profiles of the application gateway.
    '''
    return call_az("az network application-gateway ssl-profile show", locals())


def update(gateway_name, name, resource_group, cipher_suites=None, client_auth_configuration=None, disabled_ssl_protocols=None, min_protocol_version=None, policy_name=None, policy_type=None, trusted_client_certificates=None):
    '''
    Update ssl profiles of the application gateway.
    '''
    return call_az("az network application-gateway ssl-profile update", locals())




from .. pyaz_utils import call_az
from . import appsettings, environment, functions, hostname, identity, secrets, users


def list(resource_group=None):
    '''
    List all static app resources in a subscription, or in resource group if provided
    '''
    return call_az("az staticwebapp list", locals())


def show(name, resource_group=None):
    '''
    Show details of a static app.
    '''
    return call_az("az staticwebapp show", locals())


def create(branch, location, name, resource_group, source, api_location=None, app_location=None, login_with_github=None, no_wait=None, output_location=None, sku=None, tags=None, token=None):
    '''
    Create a static app with content from a GitHub repository URL and on the provided branch. If the repo is under a Github organization, please ensure that the Azure CLI Github App has access to the organization. Access can be requested in the browser when using the "--login-with-github" argument. Access must be granted by the organization's admin.
    '''
    return call_az("az staticwebapp create", locals())


def delete(name, no_wait=None, resource_group=None, yes=None):
    '''
    Delete a static app.
    '''
    return call_az("az staticwebapp delete", locals())


def disconnect(name, no_wait=None, resource_group=None):
    '''
    Disconnect source control to enable connecting to a different repo.
    '''
    return call_az("az staticwebapp disconnect", locals())


def reconnect(branch, name, source, login_with_github=None, no_wait=None, resource_group=None, token=None):
    '''
    Connect to a repo and branch following a disconnect command.
    '''
    return call_az("az staticwebapp reconnect", locals())


def update(name, branch=None, no_wait=None, sku=None, source=None, tags=None, token=None):
    '''
    Update a static app. Return the app updated.
    '''
    return call_az("az staticwebapp update", locals())




from .... pyaz_utils import call_az

def show(backup_id=None, database=None, location=None, managed_instance=None, name=None):
    '''
    Get a long term retention backup for a managed database.
    '''
    return call_az("az sql midb ltr-backup show", locals())


def list(location, database=None, database_state=None, managed_instance=None, only_latest_per_database=None, resource_group=None):
    '''
    List the long term retention backups for a location, instance or database.
    '''
    return call_az("az sql midb ltr-backup list", locals())


def delete(backup_id=None, database=None, location=None, managed_instance=None, name=None, yes=None):
    '''
    Delete a long term retention backup.
    '''
    return call_az("az sql midb ltr-backup delete", locals())


def restore(backup_id, dest_database, dest_mi, dest_resource_group, no_wait=None):
    '''
    Restore a long term retention backup to a new database.
    '''
    return call_az("az sql midb ltr-backup restore", locals())


def wait(database, managed_instance, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the managed database is met.
    '''
    return call_az("az sql midb ltr-backup wait", locals())




from .... pyaz_utils import call_az

def set(cluster_name, resource_group, parameter=None, section=None, settings_section_description=None, value=None):
    '''
    Update the settings of a cluster.
    '''
    return call_az("az sf cluster setting set", locals())


def remove(cluster_name, resource_group, parameter=None, section=None, settings_section_description=None):
    '''
    Remove settings from a cluster.
    '''
    return call_az("az sf cluster setting remove", locals())




from .... pyaz_utils import call_az

def create(account, end_ip_address, firewall_rule_name, start_ip_address, resource_group=None):
    '''
    Create a firewall rule in a Data Lake Analytics account.
    '''
    return call_az("az dla account firewall create", locals())


def update(account, firewall_rule_name, end_ip_address=None, resource_group=None, start_ip_address=None):
    '''
    Update a firewall rule in a Data Lake Analytics account.
    '''
    return call_az("az dla account firewall update", locals())


def list(account, resource_group=None):
    '''
    List firewall rules in a Data Lake Analytics account.
    '''
    return call_az("az dla account firewall list", locals())


def show(account, firewall_rule_name, resource_group=None):
    '''
    Retrieve a firewall rule in a Data Lake Analytics account.
    '''
    return call_az("az dla account firewall show", locals())


def delete(account, firewall_rule_name, resource_group=None):
    '''
    Delete a firewall rule in a Data Lake Analytics account.
    '''
    return call_az("az dla account firewall delete", locals())




from ... pyaz_utils import call_az

def create(link, target, notes=None):
    '''
    Create a new link between resources.
    '''
    return call_az("az resource link create", locals())


def delete(link):
    '''
    Delete a link between resources.
    '''
    return call_az("az resource link delete", locals())


def show(link):
    return call_az("az resource link show", locals())


def list(filter=None, scope=None):
    '''
    List resource links.
    '''
    return call_az("az resource link list", locals())


def update(link, notes=None, target=None):
    '''
    Update link between resources.
    '''
    return call_az("az resource link update", locals())




from .. pyaz_utils import call_az
from . import api, nv


def create(name, publisher_email, publisher_name, resource_group, enable_client_certificate=None, enable_managed_identity=None, location=None, no_wait=None, sku_capacity=None, sku_name=None, tags=None, virtual_network=None):
    '''
    Create an API Management service instance.
    '''
    return call_az("az apim create", locals())


def show(name, resource_group):
    '''
    Show details of an API Management service instance.
    '''
    return call_az("az apim show", locals())


def list(resource_group=None):
    '''
    List API Management service instances.
    '''
    return call_az("az apim list", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Deletes an API Management service.
    '''
    return call_az("az apim delete", locals())


def update(name, resource_group, add=None, enable_client_certificate=None, enable_managed_identity=None, force_string=None, no_wait=None, publisher_email=None, publisher_name=None, remove=None, set=None, sku_capacity=None, sku_name=None, tags=None, virtual_network=None):
    '''
    Update an API Management service instance.
    '''
    return call_az("az apim update", locals())


def check_name(name):
    return call_az("az apim check-name", locals())


def backup(backup_name, name, resource_group, storage_account_container, storage_account_key, storage_account_name, no_wait=None):
    '''
    Creates a backup of the API Management service to the given Azure Storage Account. This is long running operation and could take several minutes to complete.
    '''
    return call_az("az apim backup", locals())


def restore(backup_name, name, resource_group, storage_account_container, storage_account_key, storage_account_name, no_wait=None):
    '''
    Restores a backup of an API Management service created using the ApiManagementService_Backup operation on the current service. This is a long running operation and could take several minutes to complete.
    '''
    return call_az("az apim restore", locals())


def apply_network_updates(name, resource_group, location=None, no_wait=None):
    return call_az("az apim apply-network-updates", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of an apim is met.
    '''
    return call_az("az apim wait", locals())




from .... pyaz_utils import call_az

def list(workspace_name, is_built_in=None):
    '''
    List role definitions.
    '''
    return call_az("az synapse role definition list", locals())


def show(role, workspace_name):
    '''
    Get role definition by role id/name.
    '''
    return call_az("az synapse role definition show", locals())




from ... pyaz_utils import call_az

def attach(resource_group, vmss_name, caching=None, disk=None, instance_id=None, lun=None, size_gb=None, sku=None):
    '''
    Attach managed data disks to a scale set or its instances.
    '''
    return call_az("az vmss disk attach", locals())


def detach(lun, resource_group, vmss_name, instance_id=None):
    '''
    Detach managed data disks from a scale set or its instances.
    '''
    return call_az("az vmss disk detach", locals())




from .... pyaz_utils import call_az

def show(resource_group, workspace_name):
    '''
    Get a SQL's auditing policy.
    '''
    return call_az("az synapse sql audit-policy show", locals())


def update(resource_group, workspace_name, actions=None, add=None, blob_auditing_policy_name=None, blob_storage_target_state=None, enable_azure_monitor=None, event_hub=None, event_hub_authorization_rule_id=None, event_hub_target_state=None, force_string=None, log_analytics_target_state=None, log_analytics_workspace_resource_id=None, no_wait=None, queue_delay_time=None, remove=None, retention_days=None, set=None, state=None, storage_account=None, storage_endpoint=None, storage_key=None, storage_subscription=None, use_secondary_key=None):
    '''
    Update a SQL's auditing policy.
    '''
    return call_az("az synapse sql audit-policy update", locals())


def wait(blob_auditing_policy_name, resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition is met.
    '''
    return call_az("az synapse sql audit-policy wait", locals())




from .... pyaz_utils import call_az

def mount_rp(container_name, item_name, resource_group, rp_name, vault_name):
    '''
    Download a script which mounts files of a recovery point.
    '''
    return call_az("az backup restore files mount-rp", locals())


def unmount_rp(container_name, item_name, resource_group, rp_name, vault_name):
    '''
    Close access to the recovery point.
    '''
    return call_az("az backup restore files unmount-rp", locals())




from .... pyaz_utils import call_az

def create(database_options_json, name, project_name, resource_group, service_name, source_connection_json, target_connection_json, enable_data_integrity_validation=None, enable_query_analysis_validation=None, enable_schema_validation=None, task_type=None):
    '''
    Create and start a migration task.
    '''
    return call_az("az dms project task create", locals())


def cutover(name, object_name, project_name, resource_group, service_name):
    '''
    For an online migration task, complete the migration by performing a cutover.
    '''
    return call_az("az dms project task cutover", locals())


def delete(name, project_name, resource_group, service_name, delete_running_tasks=None, yes=None):
    '''
    Delete a migration task.
    '''
    return call_az("az dms project task delete", locals())


def list(project_name, resource_group, service_name, task_type=None):
    '''
    List the tasks within a project. Some tasks may have a status of Unknown, which indicates that an error occurred while querying the status of that task.
    '''
    return call_az("az dms project task list", locals())


def show(name, project_name, resource_group, service_name, expand=None):
    '''
    Show the details of a migration task. Use the "--expand" to get more details.
    '''
    return call_az("az dms project task show", locals())


def cancel(name, project_name, resource_group, service_name):
    '''
    Cancel a task if it's currently queued or running.
    '''
    return call_az("az dms project task cancel", locals())


def check_name(name, project_name, resource_group, service_name):
    '''
    Check if a given task name is available within a given instance of DMS as well as the name's validity.
    '''
    return call_az("az dms project task check-name", locals())




from ... pyaz_utils import call_az
from . import address_pool, frontend_ip, inbound_nat_pool, inbound_nat_rule, outbound_rule, probe, rule


def show(name, resource_group, expand=None):
    '''
    Get the details of a load balancer.
    '''
    return call_az("az network lb show", locals())


def create(name, resource_group, backend_pool_name=None, edge_zone=None, frontend_ip_name=None, frontend_ip_zone=None, location=None, no_wait=None, private_ip_address=None, private_ip_address_version=None, public_ip_address=None, public_ip_address_allocation=None, public_ip_dns_name=None, public_ip_zone=None, sku=None, subnet=None, subnet_address_prefix=None, tags=None, validate=None, vnet_address_prefix=None, vnet_name=None):
    '''
    Create a load balancer.
    '''
    return call_az("az network lb create", locals())


def delete(name, resource_group):
    '''
    Delete a load balancer.
    '''
    return call_az("az network lb delete", locals())


def list(resource_group=None):
    '''
    List load balancers.
    '''
    return call_az("az network lb list", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, expand=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the load balancer is met.
    '''
    return call_az("az network lb wait", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Update a load balancer.
    '''
    return call_az("az network lb update", locals())


def list_nic(name, resource_group):
    '''
    List associated load balancer network interfaces.
    '''
    return call_az("az network lb list-nic", locals())




from ... pyaz_utils import call_az

def list(account_name, profile_name):
    '''
    List the instructions by billing profile id.
    '''
    return call_az("az billing instruction list", locals())


def show(account_name, name, profile_name):
    '''
    Show the instruction by name. These are custom billing instructions and are only applicable for certain customers.
    '''
    return call_az("az billing instruction show", locals())


def create(account_name, name, profile_name, amount=None, creation_date=None, end_date=None, start_date=None):
    '''
    Create an instruction. These are custom billing instructions and are only applicable for certain customers.
    '''
    return call_az("az billing instruction create", locals())


def update(account_name, name, profile_name, add=None, amount=None, creation_date=None, end_date=None, force_string=None, remove=None, set=None, start_date=None):
    '''
    Update an instruction. These are custom billing instructions and are only applicable for certain customers.
    '''
    return call_az("az billing instruction update", locals())




from .... pyaz_utils import call_az

def create(kid, managed_instance, resource_group):
    '''
    Creates a SQL Instance key.
    '''
    return call_az("az sql mi key create", locals())


def delete(kid, managed_instance, resource_group):
    '''
    Deletes a SQL Instance key.
    '''
    return call_az("az sql mi key delete", locals())


def show(kid, managed_instance, resource_group):
    '''
    Shows a SQL Instance key.
    '''
    return call_az("az sql mi key show", locals())


def list(managed_instance, resource_group, filter=None):
    return call_az("az sql mi key list", locals())




from .... pyaz_utils import call_az

def list(cluster_name, name, resource_group):
    '''
    List version of a given application type.
    '''
    return call_az("az sf application-type version list", locals())


def delete(cluster_name, name, resource_group, version):
    '''
    Delete an application type version.
    '''
    return call_az("az sf application-type version delete", locals())


def show(cluster_name, name, resource_group, version):
    '''
    Show the properties of an application type version on an Azure Service Fabric cluster.
    '''
    return call_az("az sf application-type version show", locals())


def create(cluster_name, name, package_url, resource_group, version):
    '''
    Create a new application type on an Azure Service Fabric cluster.
    '''
    return call_az("az sf application-type version create", locals())




from .. pyaz_utils import call_az
from . import ase, domain, hybrid_connection, plan, vnet_integration


def list_locations(sku, linux_workers_enabled=None):
    '''
    List regions where a plan sku is available.
    '''
    return call_az("az appservice list-locations", locals())




from .... pyaz_utils import call_az

def create(account_name, name, subnet, resource_group=None, vnet_name=None):
    '''
    Creates a virtual network rule in a Data Lake Store account.
    '''
    return call_az("az dls account network-rule create", locals())


def update(account_name, name, subnet, add=None, force_string=None, remove=None, resource_group=None, set=None, vnet_name=None):
    '''
    Updates a virtual network rule in a Data Lake Store account.
    '''
    return call_az("az dls account network-rule update", locals())


def list(account_name, resource_group=None):
    '''
    Lists virtual network rules in a Data Lake Store account.
    '''
    return call_az("az dls account network-rule list", locals())


def show(account_name, name, resource_group=None):
    '''
    Get the details of a virtual network rule in a Data Lake Store account.
    '''
    return call_az("az dls account network-rule show", locals())


def delete(account_name, name, resource_group=None):
    '''
    Deletes a virtual network rule in a Data Lake Store account.
    '''
    return call_az("az dls account network-rule delete", locals())




from .... pyaz_utils import call_az

def set_permission(account, path, permission):
    '''
    Set the permissions for a file or folder in a Data Lake Store account.
    '''
    return call_az("az dls fs access set-permission", locals())


def set_owner(account, path, group=None, owner=None):
    '''
    Set the owner information for a file or folder in a Data Lake Store account.
    '''
    return call_az("az dls fs access set-owner", locals())


def show(account, path):
    '''
    Display the access control list (ACL).
    '''
    return call_az("az dls fs access show", locals())


def set_entry(account, acl_spec, path):
    '''
    Update the access control list for a file or folder.
    '''
    return call_az("az dls fs access set-entry", locals())


def set(account, acl_spec, path):
    '''
    Replace the existing access control list for a file or folder.
    '''
    return call_az("az dls fs access set", locals())


def remove_entry(account, acl_spec, path):
    '''
    Remove entries for the access control list of a file or folder.
    '''
    return call_az("az dls fs access remove-entry", locals())


def remove_all(account, path, default_acl=None):
    '''
    Remove the access control list for a file or folder.
    '''
    return call_az("az dls fs access remove-all", locals())




from ... pyaz_utils import call_az

def assign(name, resource_group, identities=None, role=None, scope=None):
    '''
    assign managed identity to the static web app
    '''
    return call_az("az staticwebapp identity assign", locals())


def remove(name, resource_group, identities=None, yes=None):
    '''
    Disable static web app's managed identity
    '''
    return call_az("az staticwebapp identity remove", locals())


def show(name, resource_group):
    '''
    display static web app's managed identity
    '''
    return call_az("az staticwebapp identity show", locals())




from ... pyaz_utils import call_az

def approve(description=None, hsm_name=None, id=None, name=None, no_wait=None, resource_group=None, vault_name=None):
    '''
    Approve a private endpoint connection request for a Key Vault/HSM.
    '''
    return call_az("az keyvault private-endpoint-connection approve", locals())


def reject(description=None, hsm_name=None, id=None, name=None, no_wait=None, resource_group=None, vault_name=None):
    '''
    Reject a private endpoint connection request for a Key Vault/HSM.
    '''
    return call_az("az keyvault private-endpoint-connection reject", locals())


def delete(hsm_name=None, id=None, name=None, no_wait=None, resource_group=None, vault_name=None):
    '''
    Delete the specified private endpoint connection associated with a Key Vault/HSM.
    '''
    return call_az("az keyvault private-endpoint-connection delete", locals())


def list(hsm_name, resource_group=None):
    '''
    List all private endpoint connections associated with a HSM.
    '''
    return call_az("az keyvault private-endpoint-connection list", locals())


def show(hsm_name=None, id=None, name=None, resource_group=None, vault_name=None):
    '''
    Show details of a private endpoint connection associated with a Key Vault/HSM.
    '''
    return call_az("az keyvault private-endpoint-connection show", locals())


def wait(created=None, custom=None, deleted=None, exists=None, hsm_name=None, id=None, interval=None, name=None, resource_group=None, timeout=None, updated=None, vault_name=None):
    '''
    Place the CLI in a waiting state until a condition of the private endpoint connection is met.
    '''
    return call_az("az keyvault private-endpoint-connection wait", locals())




from ... pyaz_utils import call_az

def assign(identity, name, resource_group):
    '''
    Assign managed identity for SignalR Service.
    '''
    return call_az("az signalr identity assign", locals())


def remove(name, resource_group):
    '''
    Remove managed identity for SignalR Service.
    '''
    return call_az("az signalr identity remove", locals())


def show(name, resource_group):
    '''
    Show managed identity for SignalR Service.
    '''
    return call_az("az signalr identity show", locals())




from ... pyaz_utils import call_az

def show(name, resource_group, slot=None):
    '''
    Show the authentification settings for the webapp.
    '''
    return call_az("az webapp auth show", locals())


def update(name, resource_group, aad_allowed_token_audiences=None, aad_client_id=None, aad_client_secret=None, aad_client_secret_certificate_thumbprint=None, aad_token_issuer_url=None, action=None, allowed_external_redirect_urls=None, enabled=None, facebook_app_id=None, facebook_app_secret=None, facebook_oauth_scopes=None, google_client_id=None, google_client_secret=None, google_oauth_scopes=None, microsoft_account_client_id=None, microsoft_account_client_secret=None, microsoft_account_oauth_scopes=None, runtime_version=None, slot=None, token_refresh_extension_hours=None, token_store=None, twitter_consumer_key=None, twitter_consumer_secret=None):
    '''
    Update the authentication settings for the webapp.
    '''
    return call_az("az webapp auth update", locals())




from .... pyaz_utils import call_az

def list(gateway_name, resource_group):
    '''
    List redirect configurations.
    '''
    return call_az("az network application-gateway redirect-config list", locals())


def show(gateway_name, name, resource_group):
    '''
    Get the details of a redirect configuration.
    '''
    return call_az("az network application-gateway redirect-config show", locals())


def delete(gateway_name, name, resource_group, no_wait=None):
    '''
    Delete a redirect configuration.
    '''
    return call_az("az network application-gateway redirect-config delete", locals())


def create(gateway_name, name, resource_group, type, include_path=None, include_query_string=None, no_wait=None, target_listener=None, target_url=None):
    '''
    Create a redirect configuration.
    '''
    return call_az("az network application-gateway redirect-config create", locals())


def update(gateway_name, name, resource_group, add=None, force_string=None, include_path=None, include_query_string=None, no_wait=None, remove=None, set=None, target_listener=None, target_url=None, type=None):
    '''
    Update a redirect configuration.
    '''
    return call_az("az network application-gateway redirect-config update", locals())




from ... pyaz_utils import call_az

def list(name, authentication_provider=None, resource_group=None):
    '''
    Lists users and assigned roles, limited to users who accepted their invites.
    '''
    return call_az("az staticwebapp users list", locals())


def invite(authentication_provider, domain, invitation_expiration_in_hours, name, roles, user_details, resource_group=None):
    '''
    Create invitation link for specified user to the static app.
    '''
    return call_az("az staticwebapp users invite", locals())


def update(name, roles, authentication_provider=None, resource_group=None, user_details=None, user_id=None):
    '''
    Updates a user entry with the listed roles. Either user details or user id is required.
    '''
    return call_az("az staticwebapp users update", locals())




from ... pyaz_utils import call_az
from . import credential


def create(name, registry, expiration=None, expiration_in_days=None, gateway=None, no_passwords=None, repository=None, resource_group=None, scope_map=None, status=None):
    '''
    Create a token associated with a scope map for an Azure Container Registry.
    '''
    return call_az("az acr token create", locals())


def delete(name, registry, resource_group=None, yes=None):
    '''
    Delete a token for an Azure Container Registry.
    '''
    return call_az("az acr token delete", locals())


def update(name, registry, resource_group=None, scope_map=None, status=None):
    '''
    Update a token (replace associated scope map) for an Azure Container Registry.
    '''
    return call_az("az acr token update", locals())


def show(name, registry, resource_group=None):
    '''
    Show details and attributes of a token for an Azure Container Registry.
    '''
    return call_az("az acr token show", locals())


def list(registry, resource_group=None):
    '''
    List all tokens for an Azure Container Registry.
    '''
    return call_az("az acr token list", locals())




from ... pyaz_utils import call_az

def create(file, name, workspace_name, executor_count=None, executor_size=None, folder_path=None, no_wait=None, spark_pool_name=None):
    '''
    Create a notebook.
    '''
    return call_az("az synapse notebook create", locals())


def set(file, name, workspace_name, executor_count=None, executor_size=None, folder_path=None, no_wait=None, spark_pool_name=None):
    '''
    Set an exist notebook.
    '''
    return call_az("az synapse notebook set", locals())


def import_(file, name, workspace_name, executor_count=None, executor_size=None, folder_path=None, no_wait=None, spark_pool_name=None):
    '''
    Import a notebook.
    '''
    return call_az("az synapse notebook import", locals())


def list(workspace_name):
    '''
    List notebooks.
    '''
    return call_az("az synapse notebook list", locals())


def show(name, workspace_name):
    '''
    Get a notebook.
    '''
    return call_az("az synapse notebook show", locals())


def export(output_folder, workspace_name, name=None):
    '''
    Export notebooks.
    '''
    return call_az("az synapse notebook export", locals())


def delete(name, workspace_name, no_wait=None, yes=None):
    '''
    Delete a notebook.
    '''
    return call_az("az synapse notebook delete", locals())




from ... pyaz_utils import call_az

def delete(assignee=None, ids=None, include_inherited=None, resource_group=None, role=None, scope=None, yes=None):
    '''
    Delete role assignments.
    '''
    return call_az("az role assignment delete", locals())


def list(all=None, assignee=None, include_classic_administrators=None, include_groups=None, include_inherited=None, resource_group=None, role=None, scope=None):
    '''
    List role assignments.
    '''
    return call_az("az role assignment list", locals())


def create(role, assignee=None, assignee_object_id=None, assignee_principal_type=None, condition=None, condition_version=None, description=None, resource_group=None, scope=None):
    '''
    Create a new role assignment for a user, group, or service principal.
    '''
    return call_az("az role assignment create", locals())


def update(role_assignment):
    '''
    Update an existing role assignment for a user, group, or service principal.
    '''
    return call_az("az role assignment update", locals())


def list_changelogs(end_time=None, start_time=None):
    '''
    List changelogs for role assignments.
    '''
    return call_az("az role assignment list-changelogs", locals())




from ... pyaz_utils import call_az

def show(endpoint_name, name, profile_name, resource_group):
    return call_az("az cdn origin-group show", locals())


def list(endpoint_name, profile_name, resource_group):
    return call_az("az cdn origin-group list", locals())


def create(endpoint_name, name, profile_name, resource_group, origins=None, probe_interval=None, probe_method=None, probe_path=None, probe_protocol=None):
    '''
    Create an origin group.
    '''
    return call_az("az cdn origin-group create", locals())


def update(endpoint_name, name, profile_name, resource_group, origins=None, probe_interval=None, probe_method=None, probe_path=None, probe_protocol=None):
    '''
    Update an origin group.
    '''
    return call_az("az cdn origin-group update", locals())


def delete(endpoint_name, name, profile_name, resource_group, yes=None):
    return call_az("az cdn origin-group delete", locals())




from ... pyaz_utils import call_az

def add(name, ip_address=None, no_wait=None, resource_group=None, subnet=None, vnet_name=None):
    return call_az("az keyvault network-rule add", locals())


def remove(name, ip_address=None, no_wait=None, resource_group=None, subnet=None, vnet_name=None):
    return call_az("az keyvault network-rule remove", locals())


def list(name, resource_group=None):
    return call_az("az keyvault network-rule list", locals())


def wait(name, created=None, custom=None, deleted=None, exists=None, interval=None, resource_group=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the vault is met.
    '''
    return call_az("az keyvault network-rule wait", locals())




from ... pyaz_utils import call_az

def show(adaptive_network_hardenings_resource_name, resource_group, resource_name, resource_namespace, resource_type):
    '''
    Gets a single Adaptive Network Hardening resource.
    '''
    return call_az("az security adaptive_network_hardenings show", locals())


def list(resource_group, resource_name, resource_namespace, resource_type):
    '''
    Gets a list of Adaptive Network Hardenings resources in scope of an extended resource.
    '''
    return call_az("az security adaptive_network_hardenings list", locals())




from .... pyaz_utils import call_az

def disable(pool_id, account_endpoint=None, account_key=None, account_name=None):
    return call_az("az batch pool autoscale disable", locals())


def enable(pool_id, account_endpoint=None, account_key=None, account_name=None, auto_scale_evaluation_interval=None, auto_scale_formula=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None):
    return call_az("az batch pool autoscale enable", locals())


def evaluate(auto_scale_formula, pool_id, account_endpoint=None, account_key=None, account_name=None):
    return call_az("az batch pool autoscale evaluate", locals())




from ... pyaz_utils import call_az

def list(name, resource_group, type=None):
    '''
    List the access keys or connection strings for a Azure Cosmos DB database account.
    '''
    return call_az("az cosmosdb keys list", locals())


def regenerate(key_kind, name, resource_group):
    '''
    Regenerate an access key for a Azure Cosmos DB database account.
    '''
    return call_az("az cosmosdb keys regenerate", locals())




from ... pyaz_utils import call_az

def list(name, resource_group):
    '''
    Get the Network access control of SignalR Service.
    '''
    return call_az("az signalr network-rule list", locals())


def update(name, resource_group, allow=None, connection_name=None, deny=None, public_network=None):
    '''
    Update the Network access control of SignalR Service.
    '''
    return call_az("az signalr network-rule update", locals())




from ... pyaz_utils import call_az

def list():
    '''
    List all security assessment results.
    '''
    return call_az("az security assessment list", locals())


def show(name, assessed_resource_id=None):
    '''
    Shows a security assessment.
    '''
    return call_az("az security assessment show", locals())


def create(name, status_code, additional_data=None, assessed_resource_id=None, status_cause=None, status_description=None):
    '''
    Creates a customer managed security assessment.
    '''
    return call_az("az security assessment create", locals())


def delete(name, assessed_resource_id=None):
    '''
    Deletes a security assessment.
    '''
    return call_az("az security assessment delete", locals())




from ... pyaz_utils import call_az

def create(group_member, location, name, resource_group, trust_scope, no_wait=None):
    '''
    Create a Server Trust Group.
    '''
    return call_az("az sql stg create", locals())


def delete(location, name, resource_group, no_wait=None, yes=None):
    '''
    Delete a Server Trust Group.
    '''
    return call_az("az sql stg delete", locals())


def show(location, name, resource_group):
    '''
    Retrieve a Server Trust Group.
    '''
    return call_az("az sql stg show", locals())


def list(resource_group, instance_name=None, location=None):
    '''
    Retrieve a list of Server Trust Groups.
    '''
    return call_az("az sql stg list", locals())




from .... pyaz_utils import call_az

def list(gateway_name, resource_group):
    '''
    List address pools.
    '''
    return call_az("az network application-gateway address-pool list", locals())


def show(gateway_name, name, resource_group):
    '''
    Get the details of an address pool.
    '''
    return call_az("az network application-gateway address-pool show", locals())


def delete(gateway_name, name, resource_group, no_wait=None):
    '''
    Delete an address pool.
    '''
    return call_az("az network application-gateway address-pool delete", locals())


def create(gateway_name, name, resource_group, no_wait=None, servers=None):
    '''
    Create an address pool.
    '''
    return call_az("az network application-gateway address-pool create", locals())


def update(gateway_name, name, resource_group, add=None, force_string=None, no_wait=None, remove=None, servers=None, set=None):
    '''
    Update an address pool.
    '''
    return call_az("az network application-gateway address-pool update", locals())




from .. pyaz_utils import call_az

def create(name, resource_group, description=None, display_name=None, location=None, tags=None, template_file=None, ui_form_definition=None, version=None, version_description=None, yes=None):
    '''
    Create a template spec and or template spec version.
    '''
    return call_az("az ts create", locals())


def update(description=None, display_name=None, name=None, resource_group=None, tags=None, template_file=None, template_spec=None, ui_form_definition=None, version=None, version_description=None, yes=None):
    '''
    Update a template spec version.
    '''
    return call_az("az ts update", locals())


def export(output_folder, name=None, resource_group=None, template_spec=None, version=None):
    '''
    Export the specified template spec version and artifacts (if any) to the specified output folder.
    '''
    return call_az("az ts export", locals())


def show(name=None, resource_group=None, template_spec=None, version=None):
    '''
    Get the specified template spec or template spec version.
    '''
    return call_az("az ts show", locals())


def list(name=None, resource_group=None):
    '''
    List template specs or template spec versions.
    '''
    return call_az("az ts list", locals())


def delete(name=None, resource_group=None, template_spec=None, version=None, yes=None):
    '''
    Delete a specified template spec or template spec version by name or resource ID..
    '''
    return call_az("az ts delete", locals())




from .. pyaz_utils import call_az
from . import monitor


def create(name, resource_group, aad_client_app_id=None, aad_client_app_secret=None, aad_tenant_id=None, compute_count=None, compute_vm_size=None, customer_admin_group_id=None, location=None, no_wait=None, subnet_prefix=None, tags=None, vnet_peer=None, vnet_prefix=None, workspace_id=None):
    '''
    Create a new Azure Red Hat OpenShift 3.11 cluster.
    '''
    return call_az("az openshift create", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete an Azure Red Hat OpenShift 3.11 cluster.
    '''
    return call_az("az openshift delete", locals())


def scale(compute_count, name, resource_group, no_wait=None):
    '''
    Scale the compute pool in an Azure Red Hat OpenShift 3.11 cluster.
    '''
    return call_az("az openshift scale", locals())


def show(name, resource_group):
    '''
    Show the details for an Azure Red Hat OpenShift 3.11 cluster.
    '''
    return call_az("az openshift show", locals())


def list(resource_group=None):
    '''
    List Azure Red Hat OpenShift 3.11 clusters.
    '''
    return call_az("az openshift list", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Wait for an Azure Red Hat OpenShift 3.11 cluster to reach a desired state.
    '''
    return call_az("az openshift wait", locals())




from .... pyaz_utils import call_az

def assign(audience, gateway_name, issuer, resource_group, tenant, no_wait=None):
    '''
    Assign/Update AAD(Azure Active Directory) authentication to a virtual network gateway.
    '''
    return call_az("az network vnet-gateway aad assign", locals())


def show(gateway_name, resource_group):
    '''
    Show AAD(Azure Active Directory) authentication of a virtual network gateway
    '''
    return call_az("az network vnet-gateway aad show", locals())


def remove(gateway_name, resource_group, no_wait=None):
    '''
    Remove AAD(Azure Active Directory) authentication from a virtual network gateway
    '''
    return call_az("az network vnet-gateway aad remove", locals())




from .... pyaz_utils import call_az

def show(account_name, resource_group):
    '''
    Show the details of encryption settings for an Azure Media Services account.
    '''
    return call_az("az ams account encryption show", locals())


def set(account_name, key_type, resource_group, current_key_id=None, key_identifier=None):
    '''
    Set the encryption settings for an Azure Media Services account.
    '''
    return call_az("az ams account encryption set", locals())




from .... pyaz_utils import call_az

def list(gateway_name, resource_group):
    '''
    List authorization certificates.
    '''
    return call_az("az network application-gateway auth-cert list", locals())


def show(gateway_name, name, resource_group):
    '''
    Show an authorization certificate.
    '''
    return call_az("az network application-gateway auth-cert show", locals())


def delete(gateway_name, name, resource_group, no_wait=None):
    '''
    Delete an authorization certificate.
    '''
    return call_az("az network application-gateway auth-cert delete", locals())


def create(cert_file, gateway_name, name, resource_group, no_wait=None):
    '''
    Create an authorization certificate.
    '''
    return call_az("az network application-gateway auth-cert create", locals())


def update(cert_file, gateway_name, name, resource_group, add=None, force_string=None, no_wait=None, remove=None, set=None):
    '''
    Update an authorization certificate.
    '''
    return call_az("az network application-gateway auth-cert update", locals())




from ... pyaz_utils import call_az
from . import api


def list(resource_group, service_name):
    '''
    Lists a collection of products in the specified service instance.
    '''
    return call_az("az apim product list", locals())


def show(product_id, resource_group, service_name):
    '''
    Gets the details of the product specified by its identifier.
    '''
    return call_az("az apim product show", locals())


def create(product_name, resource_group, service_name, approval_required=None, description=None, legal_terms=None, no_wait=None, product_id=None, state=None, subscription_required=None, subscriptions_limit=None):
    '''
    Creates a product.
    '''
    return call_az("az apim product create", locals())


def update(product_id, resource_group, service_name, add=None, approval_required=None, description=None, force_string=None, if_match=None, legal_terms=None, no_wait=None, product_name=None, remove=None, set=None, state=None, subscription_required=None, subscriptions_limit=None):
    '''
    Update existing product details.
    '''
    return call_az("az apim product update", locals())


def delete(product_id, resource_group, service_name, delete_subscriptions=None, if_match=None, no_wait=None, yes=None):
    '''
    Delete product.
    '''
    return call_az("az apim product delete", locals())


def wait(product_id, resource_group, service_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of an apim product is met.
    '''
    return call_az("az apim product wait", locals())




from ... pyaz_utils import call_az

def create(name, registry, description=None, gateway=None, repository=None, resource_group=None):
    '''
    Create a scope map for an Azure Container Registry.
    '''
    return call_az("az acr scope-map create", locals())


def delete(name, registry, resource_group=None, yes=None):
    '''
    Delete a scope map for an Azure Container Registry.
    '''
    return call_az("az acr scope-map delete", locals())


def update(name, registry, add_gateway=None, add_repository=None, description=None, remove_gateway=None, remove_repository=None, resource_group=None):
    '''
    Update a scope map for an Azure Container Registry.
    '''
    return call_az("az acr scope-map update", locals())


def show(name, registry, resource_group=None):
    '''
    Show details and attributes of a scope map for an Azure Container Registry.
    '''
    return call_az("az acr scope-map show", locals())


def list(registry, resource_group=None):
    '''
    List all scope maps for an Azure Container Registry.
    '''
    return call_az("az acr scope-map list", locals())




from .... pyaz_utils import call_az

def start(name, type, no_wait=None, resource_group=None):
    '''
    Validate/Begin migrating a storage account to enable hierarchical namespace.
    '''
    return call_az("az storage account hns-migration start", locals())


def stop(name, no_wait=None, resource_group=None):
    '''
    Stop the enabling hierarchical namespace migration of a storage account.
    '''
    return call_az("az storage account hns-migration stop", locals())




from ..... pyaz_utils import call_az

def show(circuit_name, name, peering_name, resource_group):
    return call_az("az network express-route peering peer-connection show", locals())


def list(circuit_name, peering_name, resource_group):
    return call_az("az network express-route peering peer-connection list", locals())




from .... pyaz_utils import call_az

def set(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, expiry_time=None, policy_mode=None, sas_token=None, timeout=None):
    '''
    Set blob's immutability policy.
    '''
    return call_az("az storage blob immutability-policy set", locals())


def delete(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Delete blob's immutability policy.
    '''
    return call_az("az storage blob immutability-policy delete", locals())




from ... pyaz_utils import call_az

def list(namespace=None):
    '''
    List feature registrations.
    '''
    return call_az("az feature registration list", locals())


def show(name, provider_namespace):
    return call_az("az feature registration show", locals())


def create(name, namespace):
    '''
    Create a feature registration.
    '''
    return call_az("az feature registration create", locals())


def delete(name, namespace, yes=None):
    '''
    Delete a feature registration.
    '''
    return call_az("az feature registration delete", locals())




from ..... pyaz_utils import call_az

def add(ip_address, lb_name, name, pool_name, resource_group, subnet=None, vnet=None):
    '''
    Add one backend address into the load balance backend address pool.
    '''
    return call_az("az network lb address-pool address add", locals())


def remove(lb_name, name, pool_name, resource_group):
    '''
    Remove one backend address from the load balance backend address pool.
    '''
    return call_az("az network lb address-pool address remove", locals())


def list(lb_name, pool_name, resource_group):
    '''
    List all backend addresses of the load balance backend address pool.
    '''
    return call_az("az network lb address-pool address list", locals())




from ... pyaz_utils import call_az

def create(name, resource_group, schedule_entries):
    '''
    Create patching schedule for Redis cache.
    '''
    return call_az("az redis patch-schedule create", locals())


def update(name, resource_group, schedule_entries):
    '''
    Update the patching schedule for Redis cache.
    '''
    return call_az("az redis patch-schedule update", locals())


def delete(name, resource_group):
    '''
    Deletes the patching schedule of a redis cache.
    '''
    return call_az("az redis patch-schedule delete", locals())


def show(name, resource_group):
    '''
    Gets the patching schedule of a redis cache.
    '''
    return call_az("az redis patch-schedule show", locals())




from ... pyaz_utils import call_az
from . import rule


def create(name, resource_group, location=None, tags=None):
    '''
    Create a route filter.
    '''
    return call_az("az network route-filter create", locals())


def list(resource_group=None):
    '''
    List route filters.
    '''
    return call_az("az network route-filter list", locals())


def show(name, resource_group, expand=None):
    '''
    Get the details of a route filter.
    '''
    return call_az("az network route-filter show", locals())


def delete(name, resource_group):
    '''
    Delete a route filter.
    '''
    return call_az("az network route-filter delete", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Update a route filter.
    '''
    return call_az("az network route-filter update", locals())




from ... pyaz_utils import call_az

def create(resource_group, duration=None, location=None, step=None, step_name=None, tags=None):
    '''
    Creates the step.
    '''
    return call_az("az deploymentmanager step create", locals())


def delete(resource_group, step_name):
    return call_az("az deploymentmanager step delete", locals())


def show(resource_group, step_name):
    '''
    Get the details of the step.
    '''
    return call_az("az deploymentmanager step show", locals())


def list(resource_group):
    '''
    List all steps in a resource group.
    '''
    return call_az("az deploymentmanager step list", locals())


def update(resource_group, step_name, add=None, duration=None, force_string=None, remove=None, set=None, step=None, tags=None):
    '''
    Updates the step.
    '''
    return call_az("az deploymentmanager step update", locals())




from ... pyaz_utils import call_az

def list(account_name, expand=None):
    '''
    List the agreements for a billing account.
    '''
    return call_az("az billing agreement list", locals())


def show(account_name, name, expand=None):
    '''
    Get an agreement by ID.
    '''
    return call_az("az billing agreement show", locals())




from .... pyaz_utils import call_az

def list(dps_name, resource_group):
    '''
    List all shared access policies in an Azure IoT Hub device provisioning service.
    '''
    return call_az("az iot dps access-policy list", locals())


def show(access_policy_name, dps_name, resource_group):
    '''
    Show details of a shared access policies in an Azure IoT Hub device provisioning service.
    '''
    return call_az("az iot dps access-policy show", locals())


def create(access_policy_name, dps_name, resource_group, rights, no_wait=None, primary_key=None, secondary_key=None):
    '''
    Create a new shared access policy in an Azure IoT Hub device provisioning service.
    '''
    return call_az("az iot dps access-policy create", locals())


def update(access_policy_name, dps_name, resource_group, no_wait=None, primary_key=None, rights=None, secondary_key=None):
    '''
    Update a shared access policy in an Azure IoT Hub device provisioning service.
    '''
    return call_az("az iot dps access-policy update", locals())


def delete(access_policy_name, dps_name, resource_group, no_wait=None):
    '''
    Delete a shared access policies in an Azure IoT Hub device provisioning service.
    '''
    return call_az("az iot dps access-policy delete", locals())




from .... pyaz_utils import call_az

def create(length, name, resource_group, custom_ip_prefix_name=None, edge_zone=None, location=None, tags=None, version=None, zone=None):
    '''
    Create a public IP prefix resource.
    '''
    return call_az("az network public-ip prefix create", locals())


def delete(name, resource_group):
    '''
    Delete a public IP prefix resource.
    '''
    return call_az("az network public-ip prefix delete", locals())


def list(resource_group=None):
    '''
    List public IP prefix resources.
    '''
    return call_az("az network public-ip prefix list", locals())


def show(name, resource_group, expand=None):
    '''
    Get the details of a public IP prefix resource.
    '''
    return call_az("az network public-ip prefix show", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update a public IP prefix resource.
    '''
    return call_az("az network public-ip prefix update", locals())




from ... pyaz_utils import call_az
from . import categories, subscription


def create(name, resource, event_hub=None, event_hub_rule=None, export_to_resource_specific=None, logs=None, metrics=None, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None, storage_account=None, workspace=None):
    '''
    Create diagnostic settings for the specified resource.
    '''
    return call_az("az monitor diagnostic-settings create", locals())


def show(name, resource, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None):
    return call_az("az monitor diagnostic-settings show", locals())


def list(resource, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None):
    return call_az("az monitor diagnostic-settings list", locals())


def delete(name, resource, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None):
    return call_az("az monitor diagnostic-settings delete", locals())


def update(name, resource, add=None, force_string=None, remove=None, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None, set=None):
    '''
    Update diagnostic settings.
    '''
    return call_az("az monitor diagnostic-settings update", locals())




from ... pyaz_utils import call_az
from . import ad_admin, ad_only_auth, audit_policy, conn_policy, dns_alias, firewall_rule, key, outbound_firewall_rule, tde_key, vnet_rule


def create(name, resource_group, admin_password=None, admin_user=None, assign_identity=None, enable_ad_only_auth=None, enable_public_network=None, external_admin_name=None, external_admin_principal_type=None, external_admin_sid=None, identity_type=None, key_id=None, location=None, minimal_tls_version=None, no_wait=None, primary_user_assigned_identity_id=None, restrict_outbound_network_access=None, user_assigned_identity_id=None):
    '''
    Create a server.
    '''
    return call_az("az sql server create", locals())


def delete(name, resource_group, yes=None):
    return call_az("az sql server delete", locals())


def show(name, resource_group, expand_ad_admin=None):
    return call_az("az sql server show", locals())


def list(expand_ad_admin=None, resource_group=None):
    '''
    List available servers.
    '''
    return call_az("az sql server list", locals())


def update(name, resource_group, add=None, admin_password=None, assign_identity=None, enable_public_network=None, force_string=None, identity_type=None, key_id=None, minimal_tls_version=None, no_wait=None, primary_user_assigned_identity_id=None, remove=None, restrict_outbound_network_access=None, set=None, user_assigned_identity_id=None):
    '''
    Update a server.
    '''
    return call_az("az sql server update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, expand=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the SQL server is met.
    '''
    return call_az("az sql server wait", locals())


def list_usages(name, resource_group):
    return call_az("az sql server list-usages", locals())




from .... pyaz_utils import call_az

def list(name, resource_group, top=None):
    return call_az("az group deployment operation list", locals())


def show(name, operation_ids, resource_group):
    return call_az("az group deployment operation show", locals())




from ...... pyaz_utils import call_az

def add(match_variables, name, operator, policy_name, resource_group, values, negate=None, transforms=None):
    '''
    A match condition to an application gateway WAF policy custom rule.
    '''
    return call_az("az network application-gateway waf-policy custom-rule match-condition add", locals())


def list(name, policy_name, resource_group):
    '''
    List application gateway WAF policy custom rule match conditions.
    '''
    return call_az("az network application-gateway waf-policy custom-rule match-condition list", locals())


def remove(index, name, policy_name, resource_group):
    '''
    Remove a match condition from an application gateway WAF policy custom rule.
    '''
    return call_az("az network application-gateway waf-policy custom-rule match-condition remove", locals())




from ... pyaz_utils import call_az
from . import install, permissions


def create(name, registry, audit_logs_enabled=None, client_tokens=None, log_level=None, mode=None, parent=None, repository=None, resource_group=None, sync_message_ttl=None, sync_schedule=None, sync_token=None, sync_window=None):
    '''
    Create a connected registry for an Azure Container Registry.
    '''
    return call_az("az acr connected-registry create", locals())


def delete(name, registry, cleanup=None, resource_group=None, yes=None):
    '''
    Delete a connected registry from Azure Container Registry.
    '''
    return call_az("az acr connected-registry delete", locals())


def show(name, registry, resource_group=None):
    '''
    Show connected registry details.
    '''
    return call_az("az acr connected-registry show", locals())


def deactivate(name, registry, resource_group=None, yes=None):
    '''
    Deactivate a connected registry from Azure Container Registry.
    '''
    return call_az("az acr connected-registry deactivate", locals())


def update(name, registry, add_client_tokens=None, audit_logs_enabled=None, log_level=None, remove_client_tokens=None, resource_group=None, sync_message_ttl=None, sync_schedule=None, sync_window=None):
    '''
    Update a connected registry for an Azure Container Registry.
    '''
    return call_az("az acr connected-registry update", locals())


def get_settings(name, parent_protocol, registry, generate_password=None, resource_group=None, yes=None):
    '''
    Retrieve information required to activate a connected registry, and creates or rotates the sync token credentials.
    '''
    return call_az("az acr connected-registry get-settings", locals())


def list(registry, no_children=None, parent=None, resource_group=None):
    '''
    List all the connected registries under the current parent registry.
    '''
    return call_az("az acr connected-registry list", locals())


def list_client_tokens(name, registry, resource_group=None):
    '''
    List all the client tokens associated to a specific connected registries.
    '''
    return call_az("az acr connected-registry list-client-tokens", locals())


def repo(name, registry, add=None, remove=None, resource_group=None):
    '''
    Update all the necessary connected registry sync scope maps repository permissions.
    '''
    return call_az("az acr connected-registry repo", locals())




from .. pyaz_utils import call_az
from . import link, lock


def create(properties, api_version=None, id=None, is_full_object=None, latest_include_preview=None, location=None, name=None, namespace=None, parent=None, resource_group=None, resource_type=None):
    '''
    create a resource.
    '''
    return call_az("az resource create", locals())


def delete(api_version=None, ids=None, latest_include_preview=None, name=None, namespace=None, parent=None, resource_group=None, resource_type=None):
    '''
    Delete a resource.
    '''
    return call_az("az resource delete", locals())


def show(api_version=None, ids=None, include_response_body=None, latest_include_preview=None, name=None, namespace=None, parent=None, resource_group=None, resource_type=None):
    '''
    Get the details of a resource.
    '''
    return call_az("az resource show", locals())


def list(location=None, name=None, namespace=None, resource_group=None, resource_type=None, tag=None):
    '''
    List resources.
    '''
    return call_az("az resource list", locals())


def tag(tags, api_version=None, ids=None, is_incremental=None, latest_include_preview=None, name=None, namespace=None, parent=None, resource_group=None, resource_type=None):
    '''
    Tag a resource.
    '''
    return call_az("az resource tag", locals())


def move(destination_group, ids, destination_subscription_id=None):
    return call_az("az resource move", locals())


def invoke_action(action, api_version=None, ids=None, latest_include_preview=None, name=None, namespace=None, parent=None, request_body=None, resource_group=None, resource_type=None):
    '''
    Invoke an action on the resource.
    '''
    return call_az("az resource invoke-action", locals())


def update(add=None, api_version=None, force_string=None, ids=None, include_response_body=None, latest_include_preview=None, name=None, namespace=None, parent=None, remove=None, resource_group=None, resource_type=None, set=None):
    '''
    Update a resource.
    '''
    return call_az("az resource update", locals())


def wait(api_version=None, created=None, custom=None, deleted=None, exists=None, ids=None, include_response_body=None, interval=None, name=None, namespace=None, parent=None, resource_group=None, resource_type=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a resources is met.
    '''
    return call_az("az resource wait", locals())




from ... pyaz_utils import call_az

def show(account_name, pool_name, resource_group):
    '''
    Get the specified ANF pool.
    '''
    return call_az("az netappfiles pool show", locals())


def list(account_name, resource_group):
    '''
    L:ist the ANF pools for the specified account.
    '''
    return call_az("az netappfiles pool list", locals())


def delete(account_name, pool_name, resource_group):
    '''
    Delete the specified ANF pool.
    '''
    return call_az("az netappfiles pool delete", locals())


def create(account_name, location, pool_name, resource_group, service_level, size, cool_access=None, encryption_type=None, qos_type=None, tags=None):
    '''
    Create a new Azure NetApp Files (ANF) pool.
    '''
    return call_az("az netappfiles pool create", locals())


def update(account_name, pool_name, resource_group, add=None, force_string=None, qos_type=None, remove=None, set=None, size=None, tags=None):
    '''
    Update the tags of the specified ANF pool.
    '''
    return call_az("az netappfiles pool update", locals())




from ... pyaz_utils import call_az

def list(resource_group, solution_name):
    '''
    List all yours IoT Security solution aggregated alerts.
    '''
    return call_az("az security iot-alerts list", locals())


def show(name, resource_group, solution_name):
    '''
    Shows a single aggregated alert of yours IoT Security solution.
    '''
    return call_az("az security iot-alerts show", locals())


def delete(name, resource_group, solution_name):
    '''
    Dismiss an aggregated IoT Security Alert.
    '''
    return call_az("az security iot-alerts delete", locals())




from ... pyaz_utils import call_az

def list():
    '''
    Shows the network topology in your subscription.
    '''
    return call_az("az security topology list", locals())


def show(name, resource_group):
    '''
    Shows the network topology in your subscription.
    '''
    return call_az("az security topology show", locals())




from .... pyaz_utils import call_az

def set(managed_instance, name, resource_group, retention_days, deleted_time=None, no_wait=None):
    '''
    Update short term retention for automated backups on a single database.
    '''
    return call_az("az sql midb short-term-retention-policy set", locals())


def show(managed_instance, name, resource_group, deleted_time=None):
    '''
    Show short term retention for automated backups on a single database.
    '''
    return call_az("az sql midb short-term-retention-policy show", locals())




from ... pyaz_utils import call_az

def delete(gallery_image_definition, gallery_image_version, gallery_name, resource_group):
    return call_az("az sig image-version delete", locals())


def show(gallery_image_definition, gallery_image_version, gallery_name, resource_group, expand=None):
    return call_az("az sig image-version show", locals())


def list(gallery_image_definition, gallery_name, resource_group):
    return call_az("az sig image-version list", locals())


def create(gallery_image_definition, gallery_image_version, gallery_name, resource_group, data_snapshot_luns=None, data_snapshots=None, data_vhds_luns=None, data_vhds_storage_accounts=None, data_vhds_uris=None, end_of_life_date=None, exclude_from_latest=None, location=None, managed_image=None, no_wait=None, os_snapshot=None, os_vhd_storage_account=None, os_vhd_uri=None, replica_count=None, replication_mode=None, storage_account_type=None, tags=None, target_region_encryption=None, target_regions=None):
    '''
    create a new image version
    '''
    return call_az("az sig image-version create", locals())


def update(gallery_image_definition, gallery_image_version, gallery_name, resource_group, add=None, force_string=None, no_wait=None, remove=None, replica_count=None, set=None, target_regions=None):
    '''
    update a share image version
    '''
    return call_az("az sig image-version update", locals())


def wait(gallery_image_definition, gallery_image_version, gallery_name, resource_group, created=None, custom=None, deleted=None, exists=None, expand=None, interval=None, timeout=None, updated=None):
    '''
    wait for image version related operation
    '''
    return call_az("az sig image-version wait", locals())


def list_shared(gallery_image_definition, gallery_unique_name, location, shared_to=None):
    '''
    List VM Image Versions in a gallery shared directly to your subscription or tenant (preview).
    '''
    return call_az("az sig image-version list-shared", locals())


def show_shared(gallery_image_definition, gallery_image_version, gallery_unique_name, location):
    '''
    Get an image version in a gallery shared directly to your subscription or tenant (preview).
    '''
    return call_az("az sig image-version show-shared", locals())




from .... pyaz_utils import call_az

def list_sku(name, resource_group, workspace_name):
    '''
    Returns the SKUs available for the provided resource.
    '''
    return call_az("az synapse kusto pool list-sku", locals())


def list(resource_group, workspace_name):
    '''
    List all Kusto pools.
    '''
    return call_az("az synapse kusto pool list", locals())


def show(name, resource_group, workspace_name):
    '''
    Gets a Kusto pool.
    '''
    return call_az("az synapse kusto pool show", locals())


def delete(name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Deletes a Kusto pool.
    '''
    return call_az("az synapse kusto pool delete", locals())


def list_follower_database(name, resource_group, workspace_name):
    '''
    Returns a list of databases that are owned by this Kusto Pool and were followed by another Kusto Pool.
    '''
    return call_az("az synapse kusto pool list-follower-database", locals())


def list_language_extension(name, resource_group, workspace_name):
    '''
    Returns a list of language extensions that can run within KQL queries.
    '''
    return call_az("az synapse kusto pool list-language-extension", locals())


def start(name, resource_group, workspace_name, no_wait=None):
    '''
    Starts a Kusto pool.
    '''
    return call_az("az synapse kusto pool start", locals())


def stop(name, resource_group, workspace_name, no_wait=None):
    '''
    Stops a Kusto pool.
    '''
    return call_az("az synapse kusto pool stop", locals())


def wait(name, resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the synapse kusto pool is met.
    '''
    return call_az("az synapse kusto pool wait", locals())


def create(name, resource_group, sku, workspace_name, enable_purge=None, enable_streaming_ingest=None, if_match=None, if_none_match=None, location=None, no_wait=None, optimized_autoscale=None, tags=None, workspace_uid=None):
    '''
    Create a Kusto pool.
    '''
    return call_az("az synapse kusto pool create", locals())


def update(name, resource_group, workspace_name, enable_purge=None, enable_streaming_ingest=None, if_match=None, no_wait=None, optimized_autoscale=None, sku=None, tags=None, workspace_uid=None):
    '''
    Update a Kusto Kusto Pool.
    '''
    return call_az("az synapse kusto pool update", locals())


def add_language_extension(name, resource_group, workspace_name, no_wait=None, value=None):
    '''
    Add a list of language extensions that can run within KQL queries.
    '''
    return call_az("az synapse kusto pool add-language-extension", locals())


def detach_follower_database(attached_database_configuration_name, kusto_pool_resource_id, name, resource_group, workspace_name, no_wait=None):
    '''
    Detaches all followers of a database owned by this Kusto Pool.
    '''
    return call_az("az synapse kusto pool detach-follower-database", locals())


def remove_language_extension(name, resource_group, workspace_name, no_wait=None, value=None):
    '''
    Remove a list of language extensions that can run within KQL queries.
    '''
    return call_az("az synapse kusto pool remove-language-extension", locals())




from .... pyaz_utils import call_az

def list(resource_group, webapp_name, slot=None):
    '''
    List backups of a web app.
    '''
    return call_az("az webapp config backup list", locals())


def show(resource_group, webapp_name, slot=None):
    '''
    Show the backup schedule for a web app.
    '''
    return call_az("az webapp config backup show", locals())


def create(container_url, resource_group, webapp_name, backup_name=None, db_connection_string=None, db_name=None, db_type=None, slot=None):
    '''
    Create a backup of a web app.
    '''
    return call_az("az webapp config backup create", locals())


def update(resource_group, webapp_name, backup_name=None, container_url=None, db_connection_string=None, db_name=None, db_type=None, frequency=None, retain_one=None, retention=None, slot=None):
    '''
    Configure a new backup schedule for a web app.
    '''
    return call_az("az webapp config backup update", locals())


def restore(backup_name, container_url, resource_group, webapp_name, db_connection_string=None, db_name=None, db_type=None, ignore_hostname_conflict=None, overwrite=None, slot=None, target_name=None):
    '''
    Restore a web app from a backup.
    '''
    return call_az("az webapp config backup restore", locals())




from ... pyaz_utils import call_az

def show(profile_name, resource_group, secret_name):
    return call_az("az afd secret show", locals())


def delete(profile_name, resource_group, secret_name, yes=None):
    return call_az("az afd secret delete", locals())


def list(profile_name, resource_group):
    return call_az("az afd secret list", locals())


def create(profile_name, resource_group, secret_name, secret_source, secret_version=None, use_latest_version=None):
    '''
    Creates a new secret within the specified profile.
    '''
    return call_az("az afd secret create", locals())


def update(profile_name, resource_group, secret_name, secret_source=None, secret_version=None, use_latest_version=None):
    '''
    Update an existing secret within the specified profile.
    '''
    return call_az("az afd secret update", locals())




from ... pyaz_utils import call_az

def convert(name, resource_group):
    '''
    Convert an Azure Availability Set to contain VMs with managed disks.
    '''
    return call_az("az vm availability-set convert", locals())


def create(name, resource_group, location=None, no_wait=None, platform_fault_domain_count=None, platform_update_domain_count=None, ppg=None, tags=None, unmanaged=None, validate=None):
    '''
    Create an Azure Availability Set.
    '''
    return call_az("az vm availability-set create", locals())


def delete(name, resource_group):
    '''
    Delete an availability set.
    '''
    return call_az("az vm availability-set delete", locals())


def list(resource_group=None):
    '''
    List availability sets.
    '''
    return call_az("az vm availability-set list", locals())


def list_sizes(name, resource_group):
    '''
    List VM sizes for an availability set.
    '''
    return call_az("az vm availability-set list-sizes", locals())


def show(name, resource_group):
    '''
    Get information for an availability set.
    '''
    return call_az("az vm availability-set show", locals())


def update(name, resource_group, add=None, force_string=None, ppg=None, remove=None, set=None):
    '''
    Update an Azure Availability Set.
    '''
    return call_az("az vm availability-set update", locals())




from .... pyaz_utils import call_az

def list(hub_name, resource_group=None):
    '''
    List shared access policies of an IoT hub.
    '''
    return call_az("az iot hub policy list", locals())


def show(hub_name, name, resource_group=None):
    '''
    Get the details of a shared access policy of an IoT hub.
    '''
    return call_az("az iot hub policy show", locals())


def create(hub_name, name, permissions, resource_group=None):
    '''
    Create a new shared access policy in an IoT hub.
    '''
    return call_az("az iot hub policy create", locals())


def delete(hub_name, name, resource_group=None):
    '''
    Delete a shared access policy from an IoT hub.
    '''
    return call_az("az iot hub policy delete", locals())


def renew_key(hub_name, name, renew_key, no_wait=None, resource_group=None):
    '''
    Regenerate keys of a shared access policy of an IoT hub.
    '''
    return call_az("az iot hub policy renew-key", locals())




from ... pyaz_utils import call_az

def show(lab_name, name, resource_group, expand=None):
    '''
    Show formulae from an Azure DevTest Lab.
    '''
    return call_az("az lab formula show", locals())


def list(lab_name, resource_group, expand=None, filter=None, orderby=None, top=None):
    return call_az("az lab formula list", locals())


def delete(lab_name, name, resource_group):
    return call_az("az lab formula delete", locals())


def export_artifacts(lab_name, name, resource_group):
    '''
    Export artifacts from a formula.
    '''
    return call_az("az lab formula export-artifacts", locals())




from .... pyaz_utils import call_az

def set(diffbackup_hours, name, resource_group, retention_days, server, no_wait=None):
    '''
    Update short term retention settings for a live database.
    '''
    return call_az("az sql db str-policy set", locals())


def show(name, resource_group, server):
    '''
    Show the short term retention policy for a live database.
    '''
    return call_az("az sql db str-policy show", locals())


def wait(name, policy_name, resource_group, server, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until the policy is set.
    '''
    return call_az("az sql db str-policy wait", locals())




from .... pyaz_utils import call_az
from . import throughput


def create(account_name, keyspace_name, name, resource_group, schema, analytical_storage_ttl=None, max_throughput=None, throughput=None, ttl=None):
    '''
    Create an Cassandra table under an Azure Cosmos DB Cassandra keyspace.
    '''
    return call_az("az cosmosdb cassandra table create", locals())


def update(account_name, keyspace_name, name, resource_group, analytical_storage_ttl=None, schema=None, ttl=None):
    '''
    Update an Cassandra table under an Azure Cosmos DB Cassandra keyspace.
    '''
    return call_az("az cosmosdb cassandra table update", locals())


def exists(account_name, keyspace_name, name, resource_group):
    return call_az("az cosmosdb cassandra table exists", locals())


def list(account_name, keyspace_name, resource_group):
    '''
    List the Cassandra tables under an Azure Cosmos DB Cassandra keyspace.
    '''
    return call_az("az cosmosdb cassandra table list", locals())


def show(account_name, keyspace_name, name, resource_group):
    '''
    Show the details of a Cassandra table under an Azure Cosmos DB Cassandra keyspace.
    '''
    return call_az("az cosmosdb cassandra table show", locals())


def delete(account_name, keyspace_name, name, resource_group, yes=None):
    '''
    Delete the Cassandra table under an Azure Cosmos DB Cassandra keyspace.
    '''
    return call_az("az cosmosdb cassandra table delete", locals())




from .... pyaz_utils import call_az

def update(name, registry, add=None, remove=None, resource_group=None):
    '''
    Add and remove repository permissions accross all the necessary connected registry sync scope maps.
    '''
    return call_az("az acr connected-registry permissions update", locals())


def show(name, registry, resource_group=None):
    '''
    Show the connected registry sync scope map information.
    '''
    return call_az("az acr connected-registry permissions show", locals())




from ..... pyaz_utils import call_az

def create(aggregation, metric, operator, type, dimension=None, namespace=None, num_periods=None, num_violations=None, sensitivity=None, since=None, skip_metric_validation=None, threshold=None):
    '''
    Build a metric alert rule condition.
    '''
    return call_az("az monitor metrics alert condition create", locals())




from .... pyaz_utils import call_az

def show(account_endpoint=None, account_key=None, account_name=None):
    '''
    Get lifetime summary statistics for all of the pools in a Batch account.
    '''
    return call_az("az batch pool all-statistics show", locals())




from .... pyaz_utils import call_az

def show(hsm_name=None, id=None, name=None, vault_name=None):
    '''
    Get the rotation policy of a Key Vault key.
    '''
    return call_az("az keyvault key rotation-policy show", locals())


def update(value, hsm_name=None, id=None, name=None, vault_name=None):
    '''
    Update the rotation policy of a Key Vault key.
    '''
    return call_az("az keyvault key rotation-policy update", locals())




from ... pyaz_utils import call_az
from . import blob_storage, compute_policy, data_lake_store, firewall


def create(account, default_data_lake_store, location=None, max_degree_of_parallelism=None, max_job_count=None, query_store_retention=None, resource_group=None, tags=None, tier=None):
    '''
    Create a Data Lake Analytics account.
    '''
    return call_az("az dla account create", locals())


def update(account, allow_azure_ips=None, firewall_state=None, max_degree_of_parallelism=None, max_job_count=None, query_store_retention=None, resource_group=None, tags=None, tier=None):
    '''
    Update a Data Lake Analytics account.
    '''
    return call_az("az dla account update", locals())


def list(resource_group=None):
    '''
    List available Data Lake Analytics accounts.
    '''
    return call_az("az dla account list", locals())


def show(account, resource_group=None):
    '''
    Get the details of a Data Lake Analytics account.
    '''
    return call_az("az dla account show", locals())


def delete(account, resource_group=None):
    '''
    Delete a Data Lake Analytics account.
    '''
    return call_az("az dla account delete", locals())




from .... pyaz_utils import call_az

def create(model_format, model_name, model_version, name, resource_group, scale_capacity, scale_type, deployment_name=None):
    '''
    Create a deployment for Azure Cognitive Services account.
    '''
    return call_az("az cognitiveservices account deployment create", locals())


def delete(name, resource_group, deployment_name=None):
    '''
    Delete a deployment from Azure Cognitive Services account.
    '''
    return call_az("az cognitiveservices account deployment delete", locals())


def show(name, resource_group, deployment_name=None):
    '''
    Show a deployment for Azure Cognitive Services account.
    '''
    return call_az("az cognitiveservices account deployment show", locals())


def list(name, resource_group):
    '''
    Show all deployments for Azure Cognitive Services account.
    '''
    return call_az("az cognitiveservices account deployment list", locals())




from .... pyaz_utils import call_az

def update(encryption_key_id, name, resource_group, infrastructure_encryption=None, mi_system_assigned=None, mi_user_assigned=None):
    '''
    Update encryption properties of a Recovery Services Vault.
    '''
    return call_az("az backup vault encryption update", locals())


def show(name, resource_group):
    '''
    Show details of encryption properties of a Recovery Services Vault.
    '''
    return call_az("az backup vault encryption show", locals())




from .... pyaz_utils import call_az

def create(address_pool, frontend_ip_configs, lb_name, name, protocol, resource_group, enable_tcp_reset=None, idle_timeout=None, outbound_ports=None):
    '''
    Create an outbound-rule.
    '''
    return call_az("az network lb outbound-rule create", locals())


def update(lb_name, name, resource_group, add=None, address_pool=None, enable_tcp_reset=None, force_string=None, frontend_ip_configs=None, idle_timeout=None, outbound_ports=None, protocol=None, remove=None, set=None):
    '''
    Update an outbound-rule.
    '''
    return call_az("az network lb outbound-rule update", locals())


def list(lb_name, resource_group):
    '''
    List outbound rules.
    '''
    return call_az("az network lb outbound-rule list", locals())


def show(lb_name, name, resource_group):
    '''
    Get the details of an outbound rule.
    '''
    return call_az("az network lb outbound-rule show", locals())


def delete(lb_name, name, resource_group):
    '''
    Delete an outbound-rule.
    '''
    return call_az("az network lb outbound-rule delete", locals())




from ... pyaz_utils import call_az

def list(account_name, customer_name=None, filter=None, invoice_section_name=None, profile_name=None):
    '''
    List the products for a billing account. These don't include products billed based on usage. The operation is supported for billing accounts with agreement type Microsoft Customer Agreement or Microsoft Partner Agreement.
    '''
    return call_az("az billing product list", locals())


def show(account_name, name):
    '''
    Get a product by ID. The operation is supported only for billing accounts with agreement type Microsoft Customer Agreement.
    '''
    return call_az("az billing product show", locals())


def update(account_name, name, auto_renew=None, billing_frequency=None, status=None):
    '''
    Update the properties of a Product. Currently, auto renew can be updated. The operation is supported only for billing accounts with agreement type Microsoft Customer Agreement.
    '''
    return call_az("az billing product update", locals())


def move(account_name, name, destination_invoice_section_id=None):
    '''
    Moves a product's charges to a new invoice section. The new invoice section must belong to the same billing profile as the existing invoice section. This operation is supported only for products that are purchased with a recurring charge and for billing accounts with agreement type Microsoft Customer Agreement.
    '''
    return call_az("az billing product move", locals())


def validate_move(account_name, name, destination_invoice_section_id=None):
    '''
    Validate if a product's charges can be moved to a new invoice section. This operation is supported only for products that are purchased with a recurring charge and for billing accounts with agreement type Microsoft Customer Agreement.
    '''
    return call_az("az billing product validate-move", locals())




from ..... pyaz_utils import call_az

def show(endpoint_name, profile_name, resource_group):
    '''
    Show which CDN WAF policy is applied to a CDN endpoint.
    '''
    return call_az("az cdn endpoint waf policy show", locals())


def set(endpoint_name, profile_name, resource_group, waf_policy_id=None, waf_policy_name=None, waf_policy_resource_group_name=None, waf_policy_subscription_id=None):
    '''
    Set the CDN WAF policy applied to a CDN endpoint
    '''
    return call_az("az cdn endpoint waf policy set", locals())


def remove(endpoint_name, profile_name, resource_group, yes=None):
    '''
    Remove a CDN WAF policy from a CDN endpoint.
    '''
    return call_az("az cdn endpoint waf policy remove", locals())




from .... pyaz_utils import call_az
from . import a, aaaa, caa, cname, mx, ns, ptr, soa, srv, txt


def list(resource_group, zone_name, record_type=None):
    '''
    List all record sets within a DNS zone.
    '''
    return call_az("az network dns record-set list", locals())




from .... pyaz_utils import call_az

def create(resource_group, server_name, display_name=None, no_wait=None, object_id=None):
    '''
    Create an Active Directory administrator for MySQL server.
    '''
    return call_az("az mysql server ad-admin create", locals())


def list(resource_group, server_name):
    '''
    List all Active Directory Administrators for MySQL server.
    '''
    return call_az("az mysql server ad-admin list", locals())


def delete(resource_group, server_name, yes=None):
    '''
    Delete an Active Directory Administrator for MySQL server.
    '''
    return call_az("az mysql server ad-admin delete", locals())


def show(resource_group, server_name):
    '''
    Get Active Directory Administrator information for a MySQL server.
    '''
    return call_az("az mysql server ad-admin show", locals())


def wait(resource_group, server_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the MySQL server Active Directory Administrator is met.
    '''
    return call_az("az mysql server ad-admin wait", locals())




from .... pyaz_utils import call_az
from . import custom_rule, policy_setting


def create(name, resource_group, location=None, tags=None, type=None, version=None):
    '''
    Create an application gateway WAF policy.
    '''
    return call_az("az network application-gateway waf-policy create", locals())


def delete(name, resource_group):
    '''
    Delete an application gateway WAF policy.
    '''
    return call_az("az network application-gateway waf-policy delete", locals())


def show(name, resource_group):
    '''
    Get the details of an application gateway WAF policy.
    '''
    return call_az("az network application-gateway waf-policy show", locals())


def list(resource_group=None):
    '''
    List application gateway WAF policies.
    '''
    return call_az("az network application-gateway waf-policy list", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update an application gateway WAF policy.
    '''
    return call_az("az network application-gateway waf-policy update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the application gateway WAF policy is met.
    '''
    return call_az("az network application-gateway waf-policy wait", locals())




from .... pyaz_utils import call_az

def create(name, resource_group, sku_capacity, identity_type=None, location=None, no_wait=None, sku_name=None, tags=None):
    '''
    Create a cluster instance.
    '''
    return call_az("az monitor log-analytics cluster create", locals())


def update(name, resource_group, key_name=None, key_vault_uri=None, key_version=None, sku_capacity=None, tags=None):
    '''
    Update a cluster instance.
    '''
    return call_az("az monitor log-analytics cluster update", locals())


def show(name, resource_group):
    '''
    Show the properties of a cluster instance.
    '''
    return call_az("az monitor log-analytics cluster show", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete a cluster instance.
    '''
    return call_az("az monitor log-analytics cluster delete", locals())


def list(resource_group=None):
    '''
    Gets all cluster instances in a resource group or in current subscription.
    '''
    return call_az("az monitor log-analytics cluster list", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the cluster is met.
    '''
    return call_az("az monitor log-analytics cluster wait", locals())




from .... pyaz_utils import call_az
from . import recommendation


def list(name, resource_group, server, count=None, filter=None, skip_token=None):
    '''
    Get the sensitivity classifications of a given database.
    '''
    return call_az("az sql db classification list", locals())


def show(column, name, resource_group, schema, server, table):
    '''
    Get the sensitivity classification of a given column.
    '''
    return call_az("az sql db classification show", locals())


def delete(column, name, resource_group, schema, server, table):
    '''
    Delete the sensitivity classification of a given column.
    '''
    return call_az("az sql db classification delete", locals())


def update(column, name, resource_group, schema, server, table, information_type=None, label=None):
    '''
    Update a columns's sensitivity classification.
    '''
    return call_az("az sql db classification update", locals())




from .... pyaz_utils import call_az

def list(resource_group, server_name):
    '''
    List all read replicas for a given server.
    '''
    return call_az("az mariadb server replica list", locals())


def create(name, resource_group, source_server, location=None, no_wait=None, sku_name=None):
    '''
    Create a read replica for a server.
    '''
    return call_az("az mariadb server replica create", locals())


def stop(name, resource_group, yes=None):
    '''
    Stop replication to a read replica and make it a read/write server.
    '''
    return call_az("az mariadb server replica stop", locals())




from ... pyaz_utils import call_az
from . import keys


def show(function_name, name, resource_group):
    '''
    Get the details of a function.
    '''
    return call_az("az functionapp function show", locals())


def delete(function_name, name, resource_group):
    '''
    Delete a function.
    '''
    return call_az("az functionapp function delete", locals())




from ... pyaz_utils import call_az

def create(email_address, name, password, resource_group, add_disabled=None):
    '''
    Create the Email Channel on a bot.
    '''
    return call_az("az bot email create", locals())


def show(name, resource_group, with_secrets=None):
    '''
    Get details of the email Channel on a bot
    '''
    return call_az("az bot email show", locals())


def delete(name, resource_group):
    '''
    Delete the email Channel on a bot
    '''
    return call_az("az bot email delete", locals())




from ... pyaz_utils import call_az
from . import node, vm_extension, vm_secret


def list(cluster_name, resource_group):
    '''
    List node types of a managed cluster.
    '''
    return call_az("az sf managed-node-type list", locals())


def delete(cluster_name, resource_group):
    '''
    Delete node type from a cluster.
    '''
    return call_az("az sf managed-node-type delete", locals())


def show(cluster_name, resource_group):
    '''
    Show the properties of a node type.
    '''
    return call_az("az sf managed-node-type show", locals())


def create(cluster_name, instance_count, resource_group, application_end_port=None, application_start_port=None, capacity=None, disk_size=None, disk_type=None, ephemeral_end_port=None, ephemeral_start_port=None, is_stateless=None, multiple_placement_groups=None, placement_property=None, primary=None, vm_image_offer=None, vm_image_publisher=None, vm_image_sku=None, vm_image_version=None, vm_size=None):
    '''
    Delete a managed cluster.
    '''
    return call_az("az sf managed-node-type create", locals())


def update(cluster_name, resource_group, application_end_port=None, application_start_port=None, capacity=None, ephemeral_end_port=None, ephemeral_start_port=None, instance_count=None, placement_property=None):
    '''
    Update a managed cluster.
    '''
    return call_az("az sf managed-node-type update", locals())




from .... pyaz_utils import call_az

def add(cluster_name, resource_group, admin_client_thumbprints=None, certificate_common_name=None, certificate_issuer_thumbprint=None, client_certificate_common_names=None, is_admin=None, readonly_client_thumbprints=None, thumbprint=None):
    '''
    Add a common name or certificate thumbprint to the cluster for client authentication.
    '''
    return call_az("az sf cluster client-certificate add", locals())


def remove(cluster_name, resource_group, certificate_common_name=None, certificate_issuer_thumbprint=None, client_certificate_common_names=None, thumbprints=None):
    '''
    Remove client certificates or subject names used for authentication.
    '''
    return call_az("az sf cluster client-certificate remove", locals())




from .... pyaz_utils import call_az

def delete(name, resource_group, if_match=None, no_wait=None, yes=None):
    '''
    Delete a Private DNS zone.
    '''
    return call_az("az network private-dns zone delete", locals())


def show(name, resource_group):
    '''
    Get a Private DNS zone.
    '''
    return call_az("az network private-dns zone show", locals())


def list(resource_group=None):
    '''
    List Private DNS zones.
    '''
    return call_az("az network private-dns zone list", locals())


def import_(file_name, name, resource_group):
    '''
    Create a Private DNS zone using a DNS zone file.
    '''
    return call_az("az network private-dns zone import", locals())


def export(name, resource_group, file_name=None):
    '''
    Export a Private DNS zone as a DNS zone file.
    '''
    return call_az("az network private-dns zone export", locals())


def create(name, resource_group, no_wait=None, tags=None):
    '''
    Create a Private DNS zone.
    '''
    return call_az("az network private-dns zone create", locals())


def update(name, resource_group, add=None, force_string=None, if_match=None, no_wait=None, remove=None, set=None, tags=None):
    '''
    Update a Private DNS zone's properties. Does not modify Private DNS records or virtual network links within the zone.
    '''
    return call_az("az network private-dns zone update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the Private DNS zone is met.
    '''
    return call_az("az network private-dns zone wait", locals())




from .... pyaz_utils import call_az

def list(date_time_begin, date_time_end, max_ranking, metrics, profile_name, rankings, resource_group, actions=None, rule_types=None):
    return call_az("az afd waf-log-analytic ranking list", locals())




from .... pyaz_utils import call_az

def create(location, logs, name, event_hub_auth_rule=None, event_hub_name=None, service_bus_rule=None, storage_account=None, workspace=None):
    '''
    Create diagnostic settings for a subscription
    '''
    return call_az("az monitor diagnostic-settings subscription create", locals())


def delete(name, subscription_id=None, yes=None):
    return call_az("az monitor diagnostic-settings subscription delete", locals())


def show(name, subscription_id=None):
    return call_az("az monitor diagnostic-settings subscription show", locals())


def list(subscription_id=None):
    return call_az("az monitor diagnostic-settings subscription list", locals())


def update(name, add=None, event_hub_auth_rule=None, event_hub_name=None, force_string=None, logs=None, remove=None, service_bus_rule=None, set=None, storage_account=None, subscription_id=None, workspace=None):
    '''
    Update diagnostic settings for a subscription.
    '''
    return call_az("az monitor diagnostic-settings subscription update", locals())




from ... pyaz_utils import call_az

def list(name, resource_group):
    return call_az("az cosmosdb network-rule list", locals())


def add(name, resource_group, subnet, ignore_missing_endpoint=None, vnet_name=None):
    return call_az("az cosmosdb network-rule add", locals())


def remove(name, resource_group, subnet, vnet_name=None):
    return call_az("az cosmosdb network-rule remove", locals())




from .... pyaz_utils import call_az

def add(name, password=None, repository=None, resource_group=None, suffix=None, username=None):
    '''
    Add a helm chart repository from an Azure Container Registry through the Helm CLI.
    '''
    return call_az("az acr helm repo add", locals())




from .... pyaz_utils import call_az

def show(resource_group, server):
    return call_az("az sql server tde-key show", locals())


def set(resource_group, server, server_key_type, auto_rotation_enabled=None, kid=None):
    '''
    Sets the server's encryption protector.
    '''
    return call_az("az sql server tde-key set", locals())




from .... pyaz_utils import call_az

def list(resource_group, server_name):
    '''
    List the private link resources supported for a MariaDB server.
    '''
    return call_az("az mariadb server private-link-resource list", locals())




from ... pyaz_utils import call_az

def list():
    '''
    Get details of secure score control definitions.
    '''
    return call_az("az security secure-score-control-definitions list", locals())




from .... pyaz_utils import call_az

def config_local_git(name, resource_group, slot=None):
    '''
    Get a URL for a git repository endpoint to clone and push to for function app deployment.
    '''
    return call_az("az functionapp deployment source config-local-git", locals())


def config_zip(name, resource_group, src, build_remote=None, slot=None, timeout=None):
    '''
    Perform deployment using the kudu zip push deployment for a function app.
    '''
    return call_az("az functionapp deployment source config-zip", locals())


def config(name, repo_url, resource_group, branch=None, git_token=None, github_action=None, manual_integration=None, repository_type=None, slot=None):
    '''
    Manage deployment from git or Mercurial repositories.
    '''
    return call_az("az functionapp deployment source config", locals())


def sync(name, resource_group, slot=None):
    '''
    Synchronize from the repository. Only needed under manual integration mode.
    '''
    return call_az("az functionapp deployment source sync", locals())


def show(name, resource_group, slot=None):
    '''
    Get the details of a source control deployment configuration.
    '''
    return call_az("az functionapp deployment source show", locals())


def delete(name, resource_group, slot=None):
    '''
    Delete a source control deployment configuration.
    '''
    return call_az("az functionapp deployment source delete", locals())


def update_token(git_token=None):
    return call_az("az functionapp deployment source update-token", locals())




from ... pyaz_utils import call_az

def set(key_name, key_type, name, resource_group, key_value=None, slot=None):
    '''
    Create or update a function app key.
    '''
    return call_az("az functionapp keys set", locals())


def list(name, resource_group, slot=None):
    '''
    List all function app keys.
    '''
    return call_az("az functionapp keys list", locals())


def delete(key_name, key_type, name, resource_group, slot=None):
    '''
    Delete a function app key.
    '''
    return call_az("az functionapp keys delete", locals())




from ..... pyaz_utils import call_az

def create(gateway_name, resource_group, rule_name, rule_set_name, variable, ignore_case=None, negate=None, no_wait=None, pattern=None):
    '''
    Create a rewrite rule condition.
    '''
    return call_az("az network application-gateway rewrite-rule condition create", locals())


def show(gateway_name, resource_group, rule_name, rule_set_name, variable):
    '''
    Get the details of a rewrite rule condition.
    '''
    return call_az("az network application-gateway rewrite-rule condition show", locals())


def list(gateway_name, resource_group, rule_name, rule_set_name):
    '''
    List rewrite rule conditions.
    '''
    return call_az("az network application-gateway rewrite-rule condition list", locals())


def delete(gateway_name, resource_group, rule_name, rule_set_name, variable, no_wait=None):
    '''
    Delete a rewrite rule condition.
    '''
    return call_az("az network application-gateway rewrite-rule condition delete", locals())


def update(gateway_name, resource_group, rule_name, rule_set_name, variable, add=None, force_string=None, ignore_case=None, negate=None, no_wait=None, pattern=None, remove=None, set=None):
    '''
    Update a rewrite rule condition.
    '''
    return call_az("az network application-gateway rewrite-rule condition update", locals())


def list_server_variables():
    return call_az("az network application-gateway rewrite-rule condition list-server-variables", locals())




from .... pyaz_utils import call_az

def set(enabled, gateway_name, resource_group, disabled_rule_groups=None, disabled_rules=None, exclusion=None, file_upload_limit=None, firewall_mode=None, max_request_body_size=None, no_wait=None, request_body_check=None, rule_set_type=None, rule_set_version=None):
    '''
    Update the firewall configuration of a web application.
    '''
    return call_az("az network application-gateway waf-config set", locals())


def show(gateway_name, resource_group):
    '''
    Get the firewall configuration of a web application.
    '''
    return call_az("az network application-gateway waf-config show", locals())


def list_rule_sets(group=None, type=None, version=None):
    '''
    Get information on available WAF rule sets, rule groups, and rule IDs.
    '''
    return call_az("az network application-gateway waf-config list-rule-sets", locals())




from ..... pyaz_utils import call_az

def show(account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Show the storage blob delete-policy.
    '''
    return call_az("az storage blob service-properties delete-policy show", locals())


def update(account_key=None, account_name=None, auth_mode=None, connection_string=None, days_retained=None, enable=None, sas_token=None):
    '''
    Update the storage blob delete-policy.
    '''
    return call_az("az storage blob service-properties delete-policy update", locals())




from .... pyaz_utils import call_az

def show(name, resource_group):
    '''
    Show the details of media reserved units for an Azure Media Services account. This doesn't work with accounts created with 2020-05-01 version of the Media Services API or later. Accounts created this way no longer need to set media reserved units as the system will automaticaly scale up and down based on load.
    '''
    return call_az("az ams account mru show", locals())


def set(name, resource_group, count=None, type=None):
    '''
    Set the type and number of media reserved units for an Azure Media Services account. This doesn't work with accounts created with 2020-05-01 version of the Media Services API or later. Accounts created this way no longer need to set media reserved units as the system will automaticaly scale up and down based on load.
    '''
    return call_az("az ams account mru set", locals())




from .... pyaz_utils import call_az

def add(match_variable, operator, profile_name, resource_group, rule_name, rule_set_name, match_values=None, negate_condition=None, selector=None, transform=None):
    '''
    Add a condition to a delivery rule.
    '''
    return call_az("az afd rule condition add", locals())


def remove(index, profile_name, resource_group, rule_name, rule_set_name):
    '''
    Remove a condition from a delivery rule.
    '''
    return call_az("az afd rule condition remove", locals())


def list(profile_name, resource_group, rule_name, rule_set_name):
    '''
    show condtions asscociated with the rule.
    '''
    return call_az("az afd rule condition list", locals())




from ... pyaz_utils import call_az

def list(name, resource_group, slot=None):
    '''
    list the hybrid-connections on a webapp
    '''
    return call_az("az webapp hybrid-connection list", locals())


def add(hybrid_connection, name, namespace, resource_group, slot=None):
    '''
    add an existing hybrid-connection to a webapp
    '''
    return call_az("az webapp hybrid-connection add", locals())


def remove(hybrid_connection, name, namespace, resource_group, slot=None):
    '''
    remove a hybrid-connection from a webapp
    '''
    return call_az("az webapp hybrid-connection remove", locals())




from ... pyaz_utils import call_az

def create(name, registry, count=None, no_wait=None, os=None, resource_group=None, subnet_id=None, tier=None):
    '''
    Create an agent pool for an Azure Container Registry.
    '''
    return call_az("az acr agentpool create", locals())


def update(name, registry, count=None, no_wait=None, resource_group=None):
    '''
    Update an agent pool for an Azure Container Registry.
    '''
    return call_az("az acr agentpool update", locals())


def delete(name, registry, no_wait=None, resource_group=None, yes=None):
    '''
    Delete an agent pool.
    '''
    return call_az("az acr agentpool delete", locals())


def list(registry, resource_group=None):
    '''
    List the agent pools for an Azure Container Registry.
    '''
    return call_az("az acr agentpool list", locals())


def show(name, registry, queue_count=None, resource_group=None):
    '''
    Get the properties of a specified agent pool for an Azure Container Registry.
    '''
    return call_az("az acr agentpool show", locals())




from ... pyaz_utils import call_az
from . import filter


def set(auth_mode=None, connection_string=None, description=None, endpoint=None, feature=None, key=None, label=None, name=None, yes=None):
    '''
    Set a feature flag.
    '''
    return call_az("az appconfig feature set", locals())


def delete(auth_mode=None, connection_string=None, endpoint=None, feature=None, key=None, label=None, name=None, yes=None):
    '''
    Delete feature flag.
    '''
    return call_az("az appconfig feature delete", locals())


def show(auth_mode=None, connection_string=None, endpoint=None, feature=None, fields=None, key=None, label=None, name=None):
    '''
    Show all attributes of a feature flag.
    '''
    return call_az("az appconfig feature show", locals())


def list(all=None, auth_mode=None, connection_string=None, endpoint=None, feature=None, fields=None, key=None, label=None, name=None, top=None):
    '''
    List feature flags.
    '''
    return call_az("az appconfig feature list", locals())


def lock(auth_mode=None, connection_string=None, endpoint=None, feature=None, key=None, label=None, name=None, yes=None):
    '''
    Lock a feature flag to prohibit write operations.
    '''
    return call_az("az appconfig feature lock", locals())


def unlock(auth_mode=None, connection_string=None, endpoint=None, feature=None, key=None, label=None, name=None, yes=None):
    '''
    Unlock a feature to gain write operations.
    '''
    return call_az("az appconfig feature unlock", locals())


def enable(auth_mode=None, connection_string=None, endpoint=None, feature=None, key=None, label=None, name=None, yes=None):
    '''
    Enable a feature flag to turn it ON for use.
    '''
    return call_az("az appconfig feature enable", locals())


def disable(auth_mode=None, connection_string=None, endpoint=None, feature=None, key=None, label=None, name=None, yes=None):
    '''
    Disable a feature flag to turn it OFF for use.
    '''
    return call_az("az appconfig feature disable", locals())




from .... pyaz_utils import call_az

def show_sql_access(resource_group, workspace_name):
    '''
    Show workspace's sql-access state to managed-identity.
    '''
    return call_az("az synapse workspace managed-identity show-sql-access", locals())


def grant_sql_access(resource_group, workspace_name, no_wait=None):
    '''
    Grant workspace's sql-access to managed-identity.
    '''
    return call_az("az synapse workspace managed-identity grant-sql-access", locals())


def revoke_sql_access(resource_group, workspace_name, no_wait=None):
    '''
    Revoke workspace's sql-access to managed-identity.
    '''
    return call_az("az synapse workspace managed-identity revoke-sql-access", locals())


def wait(resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of sql-access state to managed-identity is met.
    '''
    return call_az("az synapse workspace managed-identity wait", locals())




from .... pyaz_utils import call_az

def list(dps_name, resource_group):
    '''
    List all certificates contained within an Azure IoT Hub device provisioning service
    '''
    return call_az("az iot dps certificate list", locals())


def show(certificate_name, dps_name, resource_group):
    '''
    Show information about a particular Azure IoT Hub Device Provisioning Service certificate.
    '''
    return call_az("az iot dps certificate show", locals())


def create(certificate_name, dps_name, path, resource_group, verified=None):
    '''
    Create/upload an Azure IoT Hub Device Provisioning Service certificate.
    '''
    return call_az("az iot dps certificate create", locals())


def delete(certificate_name, dps_name, etag, resource_group):
    '''
    Delete an Azure IoT Hub Device Provisioning Service certificate.
    '''
    return call_az("az iot dps certificate delete", locals())


def generate_verification_code(certificate_name, dps_name, etag, resource_group):
    '''
    Generate a verification code for an Azure IoT Hub Device Provisioning Service certificate.
    '''
    return call_az("az iot dps certificate generate-verification-code", locals())


def verify(certificate_name, dps_name, etag, path, resource_group):
    '''
    Verify an Azure IoT Hub Device Provisioning Service certificate.
    '''
    return call_az("az iot dps certificate verify", locals())


def update(certificate_name, dps_name, etag, path, resource_group, verified=None):
    '''
    Update an Azure IoT Hub Device Provisioning Service certificate.
    '''
    return call_az("az iot dps certificate update", locals())




from ..... pyaz_utils import call_az

def create(gateway_name, name, peering, resource_group, associated=None, authorization_key=None, circuit_name=None, internet_security=None, labels=None, propagated=None, routing_weight=None):
    '''
    Create an ExpressRoute gateway connection.
    '''
    return call_az("az network express-route gateway connection create", locals())


def delete(gateway_name, name, resource_group):
    '''
    Delete an ExpressRoute gateway connection.
    '''
    return call_az("az network express-route gateway connection delete", locals())


def list(gateway_name, resource_group):
    '''
    List ExpressRoute gateway connections.
    '''
    return call_az("az network express-route gateway connection list", locals())


def show(gateway_name, name, resource_group):
    '''
    Get the details of an ExpressRoute gateway connection.
    '''
    return call_az("az network express-route gateway connection show", locals())


def update(gateway_name, name, resource_group, add=None, associated=None, authorization_key=None, circuit_name=None, force_string=None, internet_security=None, labels=None, peering=None, propagated=None, remove=None, routing_weight=None, set=None):
    '''
    Update an ExpressRoute gateway connection.
    '''
    return call_az("az network express-route gateway connection update", locals())




from .... pyaz_utils import call_az

def create(account_name, resource_group, name=None, new_sp_name=None, password=None, role=None, xml=None, years=None):
    '''
    Create or update a service principal and configure its access to an Azure Media Services account.
    '''
    return call_az("az ams account sp create", locals())


def reset_credentials(account_name, resource_group, name=None, password=None, role=None, xml=None, years=None):
    '''
    Generate a new client secret for a service principal configured for an Azure Media Services account.
    '''
    return call_az("az ams account sp reset-credentials", locals())




from .... pyaz_utils import call_az

def add(account_name, name, policy_option_name, resource_group, alt_rsa_token_keys=None, alt_symmetric_token_keys=None, alt_x509_token_keys=None, ask=None, audience=None, clear_key_configuration=None, fair_play_pfx=None, fair_play_pfx_password=None, fp_playback_duration_seconds=None, fp_storage_duration_seconds=None, issuer=None, open_id_connect_discovery_document=None, open_restriction=None, play_ready_template=None, rental_and_lease_key_type=None, rental_duration=None, token_claims=None, token_key=None, token_key_type=None, token_type=None, widevine_template=None):
    '''
    Add a new option to an existing content key policy.
    '''
    return call_az("az ams content-key-policy option add", locals())


def remove(account_name, name, policy_option_id, resource_group):
    '''
    Remove an option from an existing content key policy.
    '''
    return call_az("az ams content-key-policy option remove", locals())


def update(account_name, name, policy_option_id, resource_group, add_alt_token_key=None, add_alt_token_key_type=None, ask=None, audience=None, fair_play_pfx=None, fair_play_pfx_password=None, fp_playback_duration_seconds=None, fp_storage_duration_seconds=None, issuer=None, open_id_connect_discovery_document=None, play_ready_template=None, policy_option_name=None, rental_and_lease_key_type=None, rental_duration=None, token_claims=None, token_key=None, token_key_type=None, token_type=None, widevine_template=None):
    '''
    Update an option from an existing content key policy.
    '''
    return call_az("az ams content-key-policy option update", locals())




from .... pyaz_utils import call_az

def list(resource_group, workspace_name):
    '''
    List keys under specified workspace.
    '''
    return call_az("az synapse workspace key list", locals())


def show(name, resource_group, workspace_name):
    '''
    Show a workspace's key by name.
    '''
    return call_az("az synapse workspace key show", locals())


def create(key_identifier, name, resource_group, workspace_name, no_wait=None):
    '''
    Create a workspace's key.
    '''
    return call_az("az synapse workspace key create", locals())


def delete(name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Delete a workspace's key. The key at active status can't be deleted.
    '''
    return call_az("az synapse workspace key delete", locals())


def wait(key_name, resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a workspace key is met.
    '''
    return call_az("az synapse workspace key wait", locals())




from ... pyaz_utils import call_az

def set(resource_group, settings, vmss_name, no_auto_upgrade_minor_version=None, protected_settings=None, version=None):
    '''
    Enable diagnostics on a VMSS.
    '''
    return call_az("az vmss diagnostics set", locals())


def get_default_config(is_windows_os=None):
    '''
    Show the default config file which defines data to be collected.
    '''
    return call_az("az vmss diagnostics get-default-config", locals())




from .... pyaz_utils import call_az
from . import keys


def list(alias, namespace_name, resource_group):
    '''
    Shows the list of Authorization Rule by Service Bus Namespace
    '''
    return call_az("az servicebus georecovery-alias authorization-rule list", locals())


def show(alias, name, namespace_name, resource_group):
    return call_az("az servicebus georecovery-alias authorization-rule show", locals())




from ... pyaz_utils import call_az
from . import quotas


def list_skus(location, filter=None, maxresults=None):
    '''
    List virtual machine SKUs available in a location.
    '''
    return call_az("az batch location list-skus", locals())




from ... pyaz_utils import call_az

def create(gallery_image_definition, gallery_name, offer, os_type, publisher, resource_group, sku, description=None, disallowed_disk_types=None, end_of_life_date=None, eula=None, features=None, hyper_v_generation=None, location=None, maximum_cpu_core=None, maximum_memory=None, minimum_cpu_core=None, minimum_memory=None, os_state=None, plan_name=None, plan_product=None, plan_publisher=None, privacy_statement_uri=None, release_note_uri=None, tags=None):
    '''
    create a gallery image definition
    '''
    return call_az("az sig image-definition create", locals())


def list(gallery_name, resource_group):
    return call_az("az sig image-definition list", locals())


def show(gallery_image_definition, gallery_name, resource_group):
    return call_az("az sig image-definition show", locals())


def delete(gallery_image_definition, gallery_name, resource_group):
    return call_az("az sig image-definition delete", locals())


def update(gallery_image_definition, gallery_name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Update a VM Image definition.
    '''
    return call_az("az sig image-definition update", locals())


def list_shared(gallery_unique_name, location, shared_to=None):
    '''
    List VM Image definitions in a gallery shared directly to your subscription or tenant (preview).
    '''
    return call_az("az sig image-definition list-shared", locals())


def show_shared(gallery_image_definition, gallery_unique_name, location):
    '''
    Get a shared gallery image (preview).
    '''
    return call_az("az sig image-definition show-shared", locals())




from ... pyaz_utils import call_az
from . import authorization_rule, network_rule, private_endpoint_connection, private_link_resource


def create(name, resource_group, assign_identity=None, capacity=None, cluster_arm_id=None, default_action=None, disable_local_auth=None, enable_auto_inflate=None, enable_kafka=None, enable_trusted_service_access=None, location=None, maximum_throughput_units=None, sku=None, tags=None, zone_redundant=None):
    '''
    Creates the EventHubs Namespace
    '''
    return call_az("az eventhubs namespace create", locals())


def show(name, resource_group):
    '''
    shows the Event Hubs Namespace Details
    '''
    return call_az("az eventhubs namespace show", locals())


def list(resource_group=None):
    '''
    Lists the EventHubs Namespaces
    '''
    return call_az("az eventhubs namespace list", locals())


def delete(name, resource_group):
    '''
    Deletes the Namespaces
    '''
    return call_az("az eventhubs namespace delete", locals())


def exists(name):
    '''
    check for the availability of the given name for the Namespace
    '''
    return call_az("az eventhubs namespace exists", locals())


def update(name, resource_group, add=None, assign_identity=None, capacity=None, default_action=None, disable_local_auth=None, enable_auto_inflate=None, enable_kafka=None, enable_trusted_service_access=None, force_string=None, infra_encryption=None, key_name=None, key_source=None, key_vault_uri=None, key_version=None, maximum_throughput_units=None, remove=None, set=None, sku=None, tags=None):
    '''
    Updates the EventHubs Namespace
    '''
    return call_az("az eventhubs namespace update", locals())




from .... pyaz_utils import call_az

def submit(executor_size, executors, main_definition_file, name, spark_pool_name, workspace_name, archives=None, arguments=None, configuration=None, language=None, main_class_name=None, reference_files=None, tags=None):
    '''
    Submit a Spark job.
    '''
    return call_az("az synapse spark job submit", locals())


def list(spark_pool_name, workspace_name, from_index=None, size=None):
    '''
    List all Spark jobs.
    '''
    return call_az("az synapse spark job list", locals())


def show(livy_id, spark_pool_name, workspace_name):
    '''
    Get a Spark job.
    '''
    return call_az("az synapse spark job show", locals())


def cancel(livy_id, spark_pool_name, workspace_name, yes=None):
    '''
    Cancel a Spark job.
    '''
    return call_az("az synapse spark job cancel", locals())




from ... pyaz_utils import call_az

def show(container_name, item_name, name, resource_group, vault_name, backup_management_type=None, use_secondary_region=None, workload_type=None):
    '''
    Shows details of a particular recovery point.
    '''
    return call_az("az backup recoverypoint show", locals())


def list(container_name, item_name, resource_group, vault_name, backup_management_type=None, end_date=None, is_ready_for_move=None, recommended_for_archive=None, start_date=None, target_tier=None, tier=None, use_secondary_region=None, workload_type=None):
    '''
    List all recovery points of a backed up item.
    '''
    return call_az("az backup recoverypoint list", locals())


def move(container_name, destination_tier, item_name, name, resource_group, source_tier, vault_name, backup_management_type=None, workload_type=None):
    '''
    Move a particular recovery point of a backed up item from one tier to another tier.
    '''
    return call_az("az backup recoverypoint move", locals())


def show_log_chain(container_name, item_name, resource_group, vault_name, backup_management_type=None, end_date=None, start_date=None, use_secondary_region=None, workload_type=None):
    '''
    List the start and end points of the unbroken log chain(s) of the given backup item.
    '''
    return call_az("az backup recoverypoint show-log-chain", locals())




from ... pyaz_utils import call_az

def set_key(hybrid_connection, key_type, namespace, plan, resource_group):
    '''
    set the key that all apps in an appservice plan use to connect to the hybrid-connections in that appservice plan
    '''
    return call_az("az appservice hybrid-connection set-key", locals())




from .... pyaz_utils import call_az

def show(account, database_name, schema_name, statistics_name, table_name):
    return call_az("az dla catalog table-stats show", locals())


def list(account, database_name, schema_name=None, table_name=None):
    '''
    List table statistics in a database, table, or schema.
    '''
    return call_az("az dla catalog table-stats list", locals())




from .. pyaz_utils import call_az
from . import authsetting, directline, email, facebook, kik, msteams, skype, slack, sms, telegram, webchat


def create(appid, kind, name, resource_group, cmk_key_vault_key_url=None, description=None, display_name=None, echo=None, lang=None, location=None, sku=None, tags=None):
    '''
    Create a new v4 SDK bot.
    '''
    return call_az("az bot create", locals())


def publish(name, resource_group, code_dir=None, keep_node_modules=None, proj_file_path=None, timeout=None):
    '''
    Publish to a bot's associated app service.
    '''
    return call_az("az bot publish", locals())


def download(name, resource_group, save_path=None):
    '''
    Download an existing bot.
    '''
    return call_az("az bot download", locals())


def prepare_publish(name, proj_file_path, resource_group, sln_name, code_dir=None):
    '''
    (Maintenance mode) Add scripts to your local source code directory to be able to publish back using `az bot publish` for v3 SDK bots.
    '''
    return call_az("az bot prepare-publish", locals())


def prepare_deploy(lang, code_dir=None, proj_file_path=None):
    '''
    Add scripts/config files for publishing with `az webapp deployment`.
    '''
    return call_az("az bot prepare-deploy", locals())


def show(name, resource_group, msbot=None):
    '''
    Get an existing bot.
    '''
    return call_az("az bot show", locals())


def delete(name, resource_group):
    '''
    Delete an existing bot.
    '''
    return call_az("az bot delete", locals())


def update(name, resource_group, app_insights_api_key=None, app_insights_app_id=None, app_insights_key=None, cmk_key_vault_key_url=None, cmk_off=None, description=None, display_name=None, endpoint=None, icon_url=None, sku=None, tags=None):
    '''
    Update an existing bot.
    '''
    return call_az("az bot update", locals())




from .... pyaz_utils import call_az

def show(name, resource_group, server):
    return call_az("az sql server dns-alias show", locals())


def list(resource_group, server):
    return call_az("az sql server dns-alias list", locals())


def create(name, resource_group, server):
    return call_az("az sql server dns-alias create", locals())


def delete(name, resource_group, server):
    return call_az("az sql server dns-alias delete", locals())


def set(name, original_server, resource_group, server, original_resource_group=None, original_subscription_id=None):
    '''
    Sets a server to which DNS alias should point
    '''
    return call_az("az sql server dns-alias set", locals())




from ... pyaz_utils import call_az
from . import alert


def list(resource, aggregation=None, dimension=None, end_time=None, filter=None, interval=None, metadata=None, metrics=None, namespace=None, offset=None, orderby=None, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None, start_time=None, top=None):
    '''
    List the metric values for a resource.
    '''
    return call_az("az monitor metrics list", locals())


def list_definitions(resource, namespace=None, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None):
    '''
    List the metric definitions for the resource.
    '''
    return call_az("az monitor metrics list-definitions", locals())


def list_namespaces(resource_uri, start_time=None):
    '''
    List the metric namespaces for the resource.
    '''
    return call_az("az monitor metrics list-namespaces", locals())




from ... pyaz_utils import call_az
from . import create, update


def list(name=None, resource_group=None, source_id=None):
    '''
    List connections of a webapp.
    '''
    return call_az("az webapp connection list", locals())


def show(connection=None, id=None, name=None, resource_group=None):
    '''
    Get the details of a webapp connection.
    '''
    return call_az("az webapp connection show", locals())


def delete(connection=None, id=None, name=None, no_wait=None, resource_group=None, yes=None):
    '''
    Delete a webapp connection.
    '''
    return call_az("az webapp connection delete", locals())


def list_configuration(connection=None, id=None, name=None, resource_group=None):
    '''
    List source configurations of a webapp connection.
    '''
    return call_az("az webapp connection list-configuration", locals())


def validate(connection=None, id=None, name=None, resource_group=None):
    '''
    Validate a webapp connection.
    '''
    return call_az("az webapp connection validate", locals())


def list_support_types(target_type=None):
    '''
    List client types and auth types supported by webapp connections.
    '''
    return call_az("az webapp connection list-support-types", locals())


def wait(connection=None, created=None, custom=None, deleted=None, exists=None, id=None, interval=None, name=None, resource_group=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the connection is met.
    '''
    return call_az("az webapp connection wait", locals())




from ... pyaz_utils import call_az

def list(resource_group, solution_name):
    '''
    List all yours IoT Security solution aggregated recommendations.
    '''
    return call_az("az security iot-recommendations list", locals())


def show(name, resource_group, solution_name):
    '''
    Shows a single aggregated recommendation of yours IoT Security solution.
    '''
    return call_az("az security iot-recommendations show", locals())




from ... pyaz_utils import call_az

def list(resource_group, vmss_name):
    return call_az("az vmss nic list", locals())


def list_vm_nics(instance_id, resource_group, vmss_name):
    return call_az("az vmss nic list-vm-nics", locals())


def show(instance_id, name, resource_group, vmss_name, expand=None):
    return call_az("az vmss nic show", locals())

